from cyberonix.main.tools import banner, colors, template
import os
import requests
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Information_gathering")
        list_attacks = [
            " Nmap",
            " Maltego",
            " Dracnmap",
            " RED_HAWK",
            " Th3inspector",
            " Hping3",
            " Arping",
            " Netdiscover",
            " Wafw00f",
            " go back",
        ]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "0":
            print("\n[+] Nmap")
            os.system("clear")
            # name,command,discription,writeup,link=True,method="kali",github_install="",github_check=True
            github = "Nmap (Network Mapper) is a network scanner created by Gordon Lyon (also known by his pseudonym Fyodor Vaskovich). Nmap is used to discover hosts and services on a computer network by sending packets and analyzing the responses. "
            template.template(
                "nmap",
                "nmap -h",
                github.strip(),
                {
                    "Nmap Cheat-Sheet": "https://www.stationx.net/nmap-cheat-sheet/",
                    "Official website": "https://nmap.org/ ",
                    "Other resources": "https://linux.die.net/man/1/nmap",
                },
            )
        elif option == "1":
            print("\n[+] Maltego")
            os.system("clear")
            github = "Maltego is software used for open-source intelligence and forensics, developed by Paterva from Pretoria, South Africa. Maltego focuses on providing a library of transforms for discovery of data from open sources, and visualizing that information in a graph format, suitable for link analysis and data mining"
            template.template(
                "maltego",
                "maltego",
                github.strip(),
                {
                    "Official website": "https://www.maltego.com/ ",
                    "How to use it": "https://www.geeksforgeeks.org/maltego-tool-in-kali-linux/ ",
                    "Other resources": "https://www.cyberpratibha.com/information-gathering-with-maltego/ ",
                },
            )
        elif option == "2":
            print("\n[+] Dracnmap")
            os.system("clear")
            github = "Dracnmap is an open source program which is using to exploit the network and gathering information with nmap help. Nmap command comes with lots of options that can make the utility more robust and difficult to follow for new users. Hence Dracnmap is designed to perform fast scaning with the utilizing script engine of nmap and nmap can perform various automatic scanning techniques with the advanced commands."
            template.template(
                "Dracnmap",
                "./dracnmap-v2.2.sh",
                github.strip(),
                {
                    "Github website": "https://github.com/Screetsec/Dracnmap",
                    "How to use": "https://www.geeksforgeeks.org/dracnmap-information-gathering-and-network-exploitation-tool/ ",
                    "Other resources": "https://www.hacking.land/2016/10/dracnmap-exploit-network-and-gathering.html?utm_source=dlvr.it&utm_medium=facebook&m=1 ",
                },
                method="github",
                github_install="git clone https://github.com/Screetsec/Dracnmap.git && cd Dracnmap && chmod +x dracnmap-v2.2.sh",
                github_check="Dracnmap",
            )
        elif option == "3":
            print("\n[+] RED_HAWK")
            os.system("clear")
            github = "Red Hawk is a free and open-source tool available on GitHub. Red Hawk is used to scanning websites for information gathering and finding vulnerabilities. Red Hawk is written in PHP. It uses PHP script to do reconnaissance. Red Hawk is so powerful that it can detect content management system while scanning, it can detect IP address, it can detect webserver record, it can detect Cloudflare information, and can detect robots.txt. Red Hawk can detect WordPress, Drupal, Joomla, and Magento CMS. Red Hawk looks for error-based SQL injections, WordPress sensitive files, and WordPress version-related vulnerabilities. RedHawk uses different modules for doing all the scannings."
            template.template(
                "RED_HAWK",
                "php rhawk.php",
                github.strip(),
                {
                    "How to use": "https://systemweakness.com/red-hawk-an-information-gathering-tool-d12a66da7c63 ",
                    "Other resources": "https://www.geeksforgeeks.org/red-hawk-information-gathering-and-vulnerability-scanning-tool-in-kali-linux/ ",
                },
                method="github",
                github_install="git clone https://github.com/Tuhinshubhra/RED_HAWK.git",
                github_check="RED_HAWK",
            )
        elif option == "4":
            print("\n[+] Th3inspector")
            os.system("clear")
            github = "Th3inspector is an open source program which is using to exploit the network and gathering information with nmap help. Nmap command comes with lots of options that can make the utility more robust and difficult to follow for new users. Hence Dracnmap is designed to perform fast scaning with the utilizing script engine of nmap and nmap can perform various automatic scanning techniques with the advanced commands."
            template.template(
                "Th3inspector",
                "perl Th3inspector.pl",
                github.strip(),
                {
                    "github Website": "https://github.com/Moham3dRiahi/Th3inspector ",
                    "First resource": "https://www.geeksforgeeks.org/red-hawk-information-gathering-and-vulnerability-scanning-tool-in-kali-linux/ ",
                    "Second resource": "https://pentesttools.net/th3inspector-tool-for-information-gathering/",
                },
                method="github",
                github_install="git clone https://github.com/Moham3dRiahi/Th3inspector.git",
                github_check="Th3inspector",
            )
        elif option == "5":
            print("\n[+] Hping3")
            os.system("clear")
            github = "hping is a command-line oriented TCP/IP packet assembler/analyzer. It supports TCP, UDP, ICMP and RAW-IP protocols, has a traceroute mode, the ability to send files between a covered channel, and many other features."
            template.template(
                "hping3",
                "hping3 -h",
                github.strip(),
                {
                    "First resource": "https://hacksheets.in/all-categories/useful-resources-main/hping3/"
                },
            )
        elif option == "6":
            print("\n[+] Arping")
            os.system("clear")
            github = "arping is a tool for probing hosts in a network. Unlike the ping command, which operates at the network layer, arping operates at the data link layer and uses the Address Resolution Protocol (ARP). Using it involves sending ARP requests to a destination host and waiting for ARP replies."
            template.template(
                "arping",
                "arping --help",
                github.strip(),
                {
                    "First resource": "https://www.networkworld.com/article/3601693/using-the-linux-arping-command-to-ping-local-systems.html",
                    "How to use this command": "https://linuxhint.com/use-arping-command-linux/",
                    "Other resources": "https://www.baeldung.com/linux/arping-command",
                },
            )
        elif option == "7":
            print("\n[+] Netdiscover")
            os.system("clear")
            github = "Netdiscover is a command-line oriented TCP/IP packet assembler/analyzer. It supports TCP, UDP, ICMP and RAW-IP protocols, has a traceroute mode, the ability to send files between a covered channel, and many other features."
            template.template(
                "netdiscover",
                "netdiscover -help",
                github.strip(),
                {
                    "Usage in details": "https://linuxcommandlibrary.com/man/netdiscover",
                    "Second resource": "https://www.cyberpratibha.com/blog/netdiscover/",
                    "Video resources": "https://www.youtube.com/results?search_query=netdiscover+usage",
                },
            )
        elif option == "8":
            print("\n[+] Wafw00f")
            os.system("clear")
            github = "WAFW00F is a Python tool to help you fingerprint and identify Web Application Firewall (WAF) products. It is an active reconnaissance tool as it actually connects to the web server, but it starts out with a normal HTTP response and escalates as necessary."
            template.template(
                "wafw00f",
                "wafw00f --help",
                github.strip(),
                {
                    "First resource": "https://www.briskinfosec.com/tooloftheday/toolofthedaydetail/wafw00f-tool-to-fingerprint-and-identify-web-application-firewall",
                    "Second resource": "https://null-byte.wonderhowto.com/how-to/identify-web-application-firewalls-with-wafw00f-nmap-0198145/",
                    "Third resource": "https://www.geeksforgeeks.org/identification-of-web-application-firewall-using-wafw00f-in-kali-linux/",
                    "Github resource": "https://github.com/EnableSecurity/wafw00f",
                    "Video resource": "https://www.youtube.com/results?search_query=wafw00f+command+usage",
                },
            )
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner,colors,template
import os
import requests
from bs4 import BeautifulSoup

#main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Post Exploitation")
        list_attacks=["Metasploit-Framework","LinPeas","LinEnum","Sudo killer","Beroot","Linux Exploit Suggester 2","LSE (Linux Smart Enumeration) ","PSPY","Bashark","Linux Private-i","Shellter","Amber","UPX (Ultimate Packer for Executable)","Covermyass","Go Back"]
        for i in range(len(list_attacks)):
                print(colors.options,f"{i}) {list_attacks[i]}".title(),colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option=="0":
            print("\n[+] Metasploit-Framework")
            os.system("clear")
            # name,command,discription,writeup,link=True,method="kali",github_install="",github_check=True
            github = "The Metasploit Framework is an open-source tool for developing and executing exploit code against a remote target machine. It can be used to test the security of a computer system by finding and exploiting vulnerabilities. The framework includes a large collection of exploit modules, as well as various tools for payload generation, post-exploitation, and more. It can be used by security professionals for penetration testing, as well as by attackers for malicious purposes."
            template.template("metasploit-framework","msfconsole",github.strip(),{"Msf-Community-Post-Exploitation":"https://www.offensive-security.com/metasploit-unleashed/msf-community-post-exploitation","Post Exploitation In Linux With Metasploit":"https://pentestlab.blog/2013/01/04/post-exploitation-in-linux-with-metasploit/","Privilege Escalation (Metasploit Unleashed)":"https://www.offensive-security.com/metasploit-unleashed/privilege-escalation/","Post Exploitation Metasploit Modules (Reference)":"https://www.infosecmatter.com/post-exploitation-metasploit-modules-reference","PSExec Pass the Hash (Horizontal Escalation)":"https://www.offensive-security.com/metasploit-unleashed/psexec-pass-hash/","ms10_002_aurora (Vertical Escalation)":"https://www.offensive-security.com/metasploit-unleashed/privilege-escalation/","ms10_002_aurora (Horizontal Escalation)":"https://www.offensive-security.com/metasploit-unleashed/pivoting/ ","jtr_crack_fast (Hash Cracking)":"https://www.offensive-security.com/metasploit-unleashed/john-ripper/","warftpd_165_user (Keylogging)":"https://www.offensive-security.com/metasploit-unleashed/keylogging/","3proxy (Backdoor)":"https://www.offensive-security.com/metasploit-unleashed/meterpreter-backdoor/","persistence.rb (Persistent Backdoor)":"https://www.offensive-security.com/metasploit-unleashed/meterpreter-service/","Enabling Remote Desktop":"https://www.offensive-security.com/metasploit-unleashed/enabling-remote-desktop/","Post Exploitation in Linux with Metasploit":"https://pentestlab.blog/2013/01/04/post-exploitation-in-linux-with-metasploit/","Post Exploitation Metasploit Modules Reference":"https://www.infosecmatter.com/post-exploitation-metasploit-modules-reference/","Hack Like Pro: Kill and Disable Antivirus Software Remote PC":"https://null-byte.wonderhowto.com/how-to/hack-like-pro-kill-and-disable-antivirus-software-remote-pc-0141906/","Armitage Post Exploitation":"https://www.offensive-security.com/metasploit-unleashed/armitage-post-exploitation/","Setup Armitage as a Command & Control Framework for Free":"https://infosecwriteups.com/setup-armitage-as-a-command-control-c2-framework-for-free-bae590064817","Event Log Management":"https://www.offensive-security.com/metasploit-unleashed/event-log-management","Interacting with the Registry":"https://www.offensive-security.com/metasploit-unleashed/interacting-registry"})        
        elif option=="1":
            print("\n[+] LinPeas")
            os.system("clear")
            github = "LinPeas is a script that automates the process of gathering information about a Linux system, similar to Windows' PowerShell script PEAS. This script can help identify potential vulnerabilities and misconfigurations on a Linux system, as well as provide information about system and network configuration. It can be useful for penetration testing, security assessments, and incident response. The script can be executed with arguments to specify which information to gather, or without arguments to gather all available information"
            template.template("linpeas","chmod +x linpeas.sh && ./linpeas.sh -h",github.strip(),{"LinPeas Blog":"https://blog.cyberethical.me/linpeas","Linux-Privilege-Escalation":"https://delinea.com/blog/linux-privilege-escalation","Linux Privilege Escalation: Quick and Dirty":"https://johnjhacking.com/blog/linux-privilege-escalation-quick-and-dirty/","Outrunsec LinPeas":"https://outrunsec.com/tag/linpeas/","Linux-Privilege-Escalation-Suid-Binaries":"https://steflan-security.com/linux-privilege-escalation-suid-binaries"},method = "github", github_install = "wget --no-verbose https://github.com/carlospolop/PEASS-ng/releases/latest/download/linpeas.sh 2>/dev/null && mkdir LinPeas && mv linpeas.sh LinPeas", github_check = "LinPeas")
        elif option=="2":
            print("\n[+] LinEnum")
            os.system("clear")
            github = "LinEnum is a Linux enumeration script that can be used to enumerate information from a Linux system. It is designed to be run locally on a Linux system and will attempt to enumerate common files, folders, users, groups, services, configurations, and permissions. It can also be used to look for certain security vulnerabilities such as local privilege escalation. LinEnum can be run from the command line or can be automated using a script. The output of the script can be saved as a text file for later analysis."
            template.template("LinEnum","chmod +x LinEnum.sh && ./LinEnum.sh -h",github.strip(),{"Use-LinEnum-Identify-Potential-Privilege-Escalation-Vectors":"https://null-byte.wonderhowto.com/how-to/use-linenum-identify-potential-privilege-escalation-vectors-0197225/","Linux-Privilege-Escalation-With-LinEnum":"https://trevorxcohen.medium.com/linux-privilege-escalation-with-linenum-75d20a3b59f6","LinEnum-Linux-Enumeration-Privilege-Escalation-Tool":"https://www.darknet.org.uk/2014/11/linenum-linux-enumeration-privilege-escalation-tool","Linux-Privilege-Escalation-Quick-And-Dirty":"https://johnjhacking.com/blog/linux-privilege-escalation-quick-and-dirty","Linux Enumeration And Privilege Escalation – LinEnum":"https://vulners.com/n0where/N0WHERE:24819"},method = "github", github_install = "curl -s https://raw.githubusercontent.com/rebootuser/LinEnum/master/LinEnum.sh -o LinEnum.sh && mkdir LinEnum && mv LinEnum.sh LinEnum", github_check = "LinEnum")
        elif option=="3":
            print("\n[+] Sudo killer")
            os.system("clear")
            github_text_6 = github_getting_text("https://github.com/TH3xACE/SUDO_KILLER",'p[dir="auto"]',6)
            github_text_7 = github_getting_text("https://github.com/TH3xACE/SUDO_KILLER",'p[dir="auto"]',7)
            github = github_text_6 + github_text_7
            template.template("Sudo Killer","chmod u+x * && ./SUDO_KILLERv2.4.2.sh",github.strip(),{"SUDO_KILLER-Demos":"https://github.com/TH3xACE/SUDO_KILLER#demos","Sudo-Killer Briskinfosec":"https://www.briskinfosec.com/tooloftheday/toolofthedaydetail/SUDO-KILLER","Sudo-Killer-Identify-Abuse-Sudo-Misconfigurations":"https://null-byte.wonderhowto.com/how-to/use-sudo-killer-identify-abuse-sudo-misconfigurations-0202594"},method = "github", github_install = "git clone https://github.com/TH3xACE/SUDO_KILLER.git", github_check = "SUDO_KILLER")
        elif option=="4":
            print("\n[+] Beroot")
            os.system("clear")
            github_text_0 = github_getting_text("https://github.com/AlessandroZ/BeRoot",'p[dir="auto"]',0)
            github_text_1 = github_getting_text("https://github.com/AlessandroZ/BeRoot",'p[dir="auto"]',1)
            github = github_text_0 + github_text_1
            template.template("BeRoot","cd Linux && chmod u+x * && ./beroot.py",github.strip(),{"BeRoot-Linux-Privilege-Escalation":"https://www.kitploit.com/2018/06/beroot-for-linux-privilege-escalation.html?m=0","BeRoot-A-Post-Exploitation-Privilege-Escalation-Tool":"https://latesthackingnews.com/2019/08/02/beroot-a-post-exploitation-privilege-escalation-tool","BeRoot-Windows-Privilege-Escalation":"https://securityonline.info/beroot-windows-privilege-escalation"},method = "github", github_install = "git clone https://github.com/AlessandroZ/BeRoot.git", github_check = "BeRoot")
        elif option=="5":
            print("\n[+] Linux Exploit Suggester 2")
            os.system("clear")
            github = "Linux Exploit Suggester 2 (LES 2) is a tool that can be used to identify potential vulnerabilities and exploits that can be used to compromise a Linux system. It works by analyzing the running kernel version and system information, and then comparing it to a local database of known vulnerabilities and exploits. LES 2 can also be used to determine whether a patch has been applied to a specific vulnerability, making it useful for identifying systems that are still vulnerable to known exploits. The tool is open-source and can be easily installed on a Linux system. It supports a wide range of Linux distributions, including Ubuntu, Debian, Fedora, Arch Linux and more. LES 2 is a command-line tool and requires Python to run.It's a useful tool for penetration testers and system administrators to identify and prioritize vulnerabilities on their systems."
            template.template("linux-exploit-suggester-2","chmod u+x linux-exploit-suggester-2.pl && ./linux-exploit-suggester-2.pl",github.strip(),{"Kali Tools (linux-exploit-suggester)":"https://www.kali.org/tools/linux-exploit-suggester/","Find-Exploits-Get-Root-With-Linux-Exploit-Suggester":"https://null-byte.wonderhowto.com/how-to/find-exploits-get-root-with-linux-exploit-suggester-0206005","Pentest-Monkey Linux-Exploit-Suggester":"https://pentestmonkey.net/tools/audit/exploit-suggester","Linux-Exploit-Suggester-A-Kali-Linux-Tool-To-Find-The-Linux-Os-Kernel-Exploits":"https://gbhackers.com/linux-exploit-suggester-a-kali-linux-tool-to-find-the-linux-os-kernel-exploits","Securityonline Linux-Exploit Suggester":"https://securityonline.info/linux-exploit-suggester-2"},method="github",github_install="git clone https://github.com/jondonas/linux-exploit-suggester-2.git",github_check="linux-exploit-suggester-2")
        elif option=="6":
            print("\n[+] LSE (Linux Smart Enumeration)")
            os.system("clear")
            github = "Linux Smart Enumeration (LSE) is a script written by Diego Treitos that automates the enumeration process for Linux systems. It is designed to run quickly and efficiently, and to provide detailed information about the system, including users, groups, permissions, network configuration, and more. LSE is intended to be used by penetration testers and security professionals to gather information about a target system during the reconnaissance phase of an engagement."
            template.template("linux-smart-enumeration","chmod u+x lse.sh && ./lse.sh",github.strip(),{"Documentation (linux-smart-enumeration)":"https://github.com/diego-treitos/linux-smart-enumeration/blob/master/README.md","Use-Linux-Smart-Enumeration-Discover-Paths-Privesc":"https://null-byte.wonderhowto.com/how-to/use-linux-smart-enumeration-discover-paths-privesc-0330807","Hakin9 linux-smart-enumeration":"https://hakin9.org/linux-smart-enumeration"},method="github",github_install="git clone https://github.com/diego-treitos/linux-smart-enumeration.git",github_check="linux-smart-enumeration")
        elif option=="7":
            print("\n[+] PSPY")
            os.system("clear")
            github_text_0=github_getting_text("https://github.com/DominicBreuker/pspy",'p[dir="auto"]',2)
            github_text_1=github_getting_text("https://github.com/DominicBreuker/pspy",'p[dir="auto"]',3)
            github = github_text_0 + github_text_1
            version = github_getting_text("https://github.com/DominicBreuker/pspy/releases/",'div[class="css-truncate css-truncate-target"]',0).strip()
            template.template("pspy64","chmod u+x pspy64 && ./pspy64",github.strip(),{"Using-PSPY-To-Monitor-Linux-Processes":"https://infinitelogins.com/2020/09/04/using-ps-py-to-monitor-linux-processes","Cyberkendra Pspy-Tool-Monitor-Linux-Processes":"https://tools.cyberkendra.com/2020/04/pspy-tool-monitor-linux-processes.html","How-To-Enumerate-Services-In-Use-With-PSPY":"https://vk9-sec.com/how-to-enumerate-services-in-use-with-pspy","TryHackMe-ConvertMyVideo Writeup":"https://sparshjazz.medium.com/tryhackme-convertmyvideo-writeup-56b6c8217001","Bootlesshacker PSPY":"https://www.bootlesshacker.com/tag/pspy","SecurityOnline PSPY":"https://securityonline.info/pspy"},method="github",github_install=f"wget --no-verbose https://github.com/DominicBreuker/pspy/releases/download/{version}/pspy64 2>/dev/null && mkdir PSPY && mv pspy64 PSPY",github_check="PSPY")
        elif option=="8":
            print("\n[+] Bashark")
            os.system("clear")
            github = "Bashark is an open-source tool developed by redcode-labs that allows you to perform reconnaissance on a target by using various command-line tools and APIs. It can be used to gather information about a target's IP address, DNS information, WHOIS information, and more. Bashark is written in Bash and can be run on Linux and macOS systems. It is commonly used by penetration testers and security researchers to gather information during the reconnaissance phase of a penetration testing engagement"
            template.template("Bashark","chmod u+x bashark.sh && ./bashark.sh",github.strip(),{"Documentation":"https://github.com/redcode-labs/Bashark/blob/master/README.md","SecurityOnline-Bashark":"https://securityonline.info/bashark/","Bashark-Bash-Post-Exploitation-Toolkit":"https://www.kitploit.com/2018/10/bashark-bash-post-exploitation-toolkit.html"},method = "github", github_install = "curl -s https://raw.githubusercontent.com/redcode-labs/Bashark/master/bashark.sh -o bashark.sh && mkdir Bashark && mv bashark.sh Bashark", github_check = "Bashark")
        elif option=="9":
            print("\n[+] Linux Private-i")
            os.system("clear")
            github = "A Linux Enumeration & Privilege Escalation tool that automates the basic enumeration steps and displays the results in an easily readable format. The script comes loaded with a variety of 4 Options to choose from. Using Bash, execute private-i.sh on the local low privileged user. Select an option, execute & watch the show. Each mode uses common Linux binaries to enumerate the local system (find, grep, ps, etc). If you have a non-bash shell such as sh, use Noir-Private-i. Either script will not write or auto-exploit in any way"
            template.template("Linux Private-i","chmod u+x private-i.sh && ./private-i.sh",github.strip(),{"Documentation":"https://github.com/rtcrowley/linux-private-i/blob/master/README.md","HackingArticles-linux-privilege-escalation-automated-script":"https://www.hackingarticles.in/linux-privilege-escalation-automated-script"},method = "github", github_install = "curl -s https://raw.githubusercontent.com/rtcrowley/linux-private-i/master/private-i.sh -o private-i.sh && mkdir Private-i && mv private-i.sh Private-i", github_check = "Private-i")
        elif option=="10":
            print("\n[+] Shellter")
            os.system("clear")
            github = "Shellter is a dynamic shellcode injection tool aka dynamic PE infector. It can be used in order to inject shellcode into native Windows applications (currently 32-bit apps only). The shellcode can be something yours or something generated through a framework, such as Metasploit. Shellter takes advantage of the original structure of the PE file and doesn't apply any  modification such as changing memory access permissions in sections (unless the user wants to), adding an extra section with RWE access, and whatever would look dodgy under an AV scan. Shellter is not just an EPO infector that tries to find a location to insert an instruction to redirect execution to the payload. Unlike any other infector, Shellter’s advanced infection engine never transfers the execution flow to a code cave or to an added section in the infected PE file. Shellter uses a unique dynamic approach which is based on the execution flow of the target application. This means that no static/predefined locations are used for shellcode injection. Shellter will launch and trace the target, while at the same time will log the execution flow of the application."
            template.template("shellter","shellter",github.strip(),{"Introduction to Shellter": "https://github.com/ParrotSec/shellter#readme","Tool documentation for Shellter on Kali Linux": "https://www.kali.org/tools/shellter/#tool-documentation","Anti-virus Bypass with Shellter 5.1 on Kali Linux": "https://cyberarms.wordpress.com/2015/10/04/anti-virus-bypass-with-shellter-5-1-on-kali-linux/","Shellter: A Shellcode Injecting Tool": "https://www.hackingarticles.in/shellter-a-shellcode-injecting-tool/","Shellter - The Ultimate Tool for AV Evasion": "https://metalkey.github.io/shellter---the-ultimate-tool-for-av-evasion.html","Hack like a Pro: Evade AV Software with Shellter": "https://null-byte.wonderhowto.com/how-to/hack-like-pro-evade-av-software-with-shellter-0168504/"})    
        elif option=="11":
            print("\n[+] Amber")
            os.system("clear")
            github=github_getting_text("https://github.com/EgeBalci/amber",'p[dir="auto"]',1)
            template.template("Amber","chmod u+x amber && ./amber",github.strip(),{"Amber README":"https://github.com/EgeBalci/amber/blob/master/README.md","Amber Video - 1 ":"https://www.youtube.com/watch?v=3en0ftnjEpE","Amber Video - 2 ":"https://www.youtube.com/watch?v=lCPdKSH6RMc","Amber Usage":"https://raw.githubusercontent.com/EgeBalci/amber/master/img/usage.gif"},method = "github", github_install = "wget --no-verbose https://github.com/EgeBalci/amber/releases/download/v3.1/amber_linux_amd64_3.1.zip 2>/dev/null && unzip -qq amber_linux_amd64_3.1.zip && rm amber_linux_amd64_3.1.zip", github_check = "amber_linux_amd64_3.1")    
        elif option=="12":
            print("\n[+] UPX (Ultimate Packer for Executable)")
            os.system("clear")
            github = "UPX is a free, portable, extendable, high-performance executable packer for several different executable formats. It can be used to compress and obfuscate executable files to make them smaller and more difficult to reverse engineer. UPX supports a wide range of file formats, including Windows PE, Linux ELF, and more. UPX is available for a variety of platforms, including Windows, Linux, and macOS. The UPX compression algorithm is designed to compress the code section of an executable file, while leaving the data section uncompressed. This allows the compressed code to be executed directly from memory without the need to decompress it first. UPX is open-source and actively maintained, with updates and bug fixes released regularly."
            template.template("UPX (Ultimate Packer for Executable)","chmod u+x upx && ./upx",github.strip(),{"UPX README":"https://github.com/upx/upx#readme","UPX Video - 1 ":"https://www.youtube.com/watch?v=upTXpDhI0ww"},method = "github", github_install = "wget --no-verbose https://github.com/upx/upx/releases/download/v4.0.1/upx-4.0.1-i386_linux.tar.xz 2>/dev/null && tar -xf upx-4.0.1-i386_linux.tar.xz && rm upx-4.0.1-i386_linux.tar.xz", github_check = "upx-4.0.1-i386_linux")    
        elif option=="13":
            print("\n[+] Covermyass")
            os.system("clear")
            github=github_getting_text("https://github.com/sundowndev/covermyass",'p[dir="auto"]',1)
            template.template("Covermyass","chmod u+x covermyass_linux_amd64 && ./covermyass_linux_amd64",github.strip(),{"CoverMyAss README":"https://github.com/sundowndev/covermyass/blob/master/README.md","Clearing or Removing Tracks":"https://b14cky-notes.gitbook.io/untitled/"},method = "github", github_install = "wget --no-verbose https://github.com/sundowndev/covermyass/releases/download/v2.0.0-beta5/covermyass_linux_amd64 2>/dev/null && mkdir Covermyass && mv covermyass_linux_amd64 Covermyass", github_check = "Covermyass")    
        else:
            return
def github_getting_text(link,selector,indexvalue):
    print("Please Wait....\r",end="")
    URL = link
    # try:
    r = requests.get(URL)
    soup = BeautifulSoup(r.content, 'html.parser')
    paras = soup.select(selector)
    #check index value from test file
    return paras[indexvalue].text
    # except:
    #     return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"

if __name__=='__main__':
    main()



from cyberonix.main.tools import banner,run_on_browser,colors,template
import os
import threading,inspect
def main():
    if inspect.stack()[1].function != "main":
        if not main.called:
              main.called=True
              start()
    else:
        start()
def start():  
        os.system("clear")
        banner.main()
        banner.attack("Cheat Sheet")
        cheat({"Nmap cheatsheet" : "https://www.tutorialspoint.com/nmap-cheat-sheet","Maltego cheatsheet" : "https://static.maltego.com/cdn/case%20studies/building-integrations-for-maltego-cheat-sheet.pdf","Hping3 cheatsheet" : "https://cyberwar.nl/d/cheatsheets/hping3_cheatsheet_v1.0-ENG.pdf","Netdiscover cheatsheet" : "https://linuxcommandlibrary.com/man/netdiscover","Wafw00f cheatsheet" : "https://cheatsheet.haax.fr/web-pentest/applicative-scans/web_application_firewall/", "Metasploit-Framework cheatsheet" : "https://cdn.comparitech.com/wp-content/uploads/2019/06/Metasploit-Cheat-Sheet-1.webp", "Wireshark cheatsheet" : "https://www.stationx.net/wireshark-cheat-sheet/", "Bettercap cheatsheet" : "https://www.bettercap.org/usage/interactive/", "Tcpdump cheatsheet" : "https://cdn.comparitech.com/wp-content/uploads/2019/06/tcpdump-cheat-sheet-1.pdf", "Scapy cheatsheet" : "https://wiki.sans.blue/Tools/pdfs/ScapyCheatSheet_v0.2.pdf", "Responder cheatsheet" : "https://www.ivoidwarranties.tech/posts/pentesting-tuts/responder/cheatsheet/", "Airgeddon cheatsheet" : "https://liodeus.github.io/2020/10/29/OSWP-personal-cheatsheet.html#airgeddon", "Wpscan cheatsheet" : "https://linuxcommandlibrary.com/man/wpscan","Wapiti cheatsheet" : "https://wapiti.limsi.fr/manual.html","Legion cheatsheet" : "https://theory.stanford.edu/~aiken/LegionRetreat21/slides/Tools.pdf","Nikto cheatsheet" : "https://cdn.comparitech.com/wp-content/uploads/2019/07/NIkto-Cheat-Sheet.pdf", "Burp Suite cheatsheet" : "https://portswigger.net/burp/documentation/desktop","Owasp ZAP cheatsheet" : "https://www.zaproxy.org/docs/desktop/cmdline/","Nessus cheatsheet" : "https://limberduck.github.io/nessus-cheat-sheet/nessus-cheat-sheet.pdf","dirb cheatsheet" : "https://manpages.debian.org/unstable/dirb/dirb.1.en.html","skipfish cheatsheet" : "https://linux.die.net/man/1/skipfish","Nuclei cheatsheet" : "https://cheatsheet.haax.fr/web-pentest/tools/nuclei/", "Wifite cheatsheet" : "https://cheatography.com/socket23/cheat-sheets/wifite/", "Aircrack-ng cheatsheet" : "https://www.cyberfella.co.uk/rhel/aircrack-ng-suite.pdf"}, "cheatSheet")

def exit_program():
        os.system("clear")
        banner.main()
        print("\033[38;5;105m","[+] Thanks visit again".title())


def cheat(cheatSheet,name):
    while True:
        os.system("clear")
        banner.main()   
        banner.attack(name.title())

        key=list(cheatSheet.keys())
        key.append("go back".title())
        for i in range(len(key)):
            print(colors.options,f"{i}) {key[i]}".title(),colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        try:
            threading.Thread(target=run_on_browser.main, args=(cheatSheet[key[int(option)]],)).start()             
        except:
            exit_program()
            return
main.called=False

if __name__ == "__main__": 
    main()




from cyberonix.main.tools import banner,colors,template
import os
from cyberonix.main.tools import writeup
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Cryptography Failure")
        list_root_attacks=["Tool","Writeups","go back"]
        for i in range(len(list_root_attacks)):
            print(colors.options, f"{i}) {list_root_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "0":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Tools")
                list_attacks=["SSLstript","Bettercap","Ettercap (Graphical of bettercap)","sslyze","O-Saft","sslscan","SSLLabs","go back"]
                for i in range(len(list_attacks)):
                    print(colors.options,f"{i}) {list_attacks[i]}".title(),colors.reset)
                try:
                    option2 = input(f"\n {colors.select}Select An Option ->  {colors.reset}")
                except KeyboardInterrupt:
                    template.exit_program()
                if option2=="0":
                    print(f"\n[+] SSLstrip")
                    os.system("clear")
                    github = "SSLStrip is a powerful hacking tool that enables an attacker to intercept and manipulate HTTPS traffic between a user and a website. The tool works by downgrading HTTPS connections to insecure HTTP connections, which allows an attacker to eavesdrop on the traffic and steal sensitive information such as login credentials, credit card numbers, and other personal data. SSLStrip is commonly used in phishing attacks and other cybercriminal activities. It can be a potent weapon in the hands of skilled hackers who are looking to exploit vulnerabilities in web security."
                    template.template("sslstrip","sslstrip -h",github.strip(),{"SSLstrip Tutorial Beginner":"https://www.computerweekly.com/tip/Sslstrip-tutorial-for-penetration-testers","SSLstip how awesome tool is ts":"https://infosecwriteups.com/ssl-strip-how-awesome-it-is-a0eb79e28bcc","ARP Spoofing and SSL Stripping":"https://levelup.gitconnected.com/ethical-hacking-part-10-arp-spoofing-ssl-strip-ea5f0cc892f3"})
                elif option2=="1":
                    print(f"\n[+] Bettercap")
                    os.system("clear")
                    github = "Bettercap is a network security tool used for advanced network analysis, monitoring, and penetration testing. It allows users to sniff and intercept network traffic, perform man-in-the-middle attacks, and perform various other types of network-related exploits. Bettercap can be used for various tasks such as ARP spoofing, DNS spoofing, HTTP proxying, packet sniffing, password sniffing, and many more. The tool is highly customizable and offers a user-friendly interface. It is popular among security researchers and penetration testers due to its effectiveness and reliability."
                    template.template('bettercap','bettercap',github.strip(),{"HSTS Hijacking using Bettercap": "https://github.com/bettercap/caplets/blob/master/hstshijack/README.md","SSL Stripping by B14CKY": "https://www.youtube.com/watch?v=Peu0AEpHUVs",})
                elif option2=="2":
                    print("\n[+] Ettercap (Graphical of bettercap)")
                    os.system("clear")
                    github="Ettercap is a popular open-source GUI network security tool that is used for monitoring and analyzing network traffic in real-time. It can be used to perform various types of attacks such as ARP spoofing, IP and MAC address spoofing, session hijacking, DNS spoofing, etc. Ettercap is commonly used by network administrators and security experts to test the security of their own networks and to identify potential vulnerabilities. It supports various protocols like TCP, UDP, ICMP, and can also decode SSL traffic. Ettercap can be used on various operating systems including Windows, Linux, and Mac OS X."
                    template.template("ettercap-graphical","ettercap -G",github.strip(),{"SSLStriping Using Ettercap by NULL-BYTE': 'https://null-byte.wonderhowto.com/forum/struggling-perform-mitm-attack-using-ettercap-and-sslstrip-0165933/','HSTS Hijacing': 'https://github.com/bettercap/caplets/blob/master/hstshijack/README.md",})
                elif option2=="3":
                    print("\n[+] sslyze")
                    os.system("clear")
                    github="SSLyze is a Python-based command-line tool that helps in evaluating the SSL/TLS security posture of a given target. It allows users to analyze SSL/TLS configuration on a server and detect various security issues like weak ciphers, certificate issues, and misconfigurations. SSLyze is useful for system administrators, security professionals, and developers to test and evaluate the security of SSL/TLS implementations. It is an open-source tool and is available for free under the GPL v3 license."
                    template.template("sslyze","sslyze -h",github.strip(),{"SSLyze by GeeksforGeeks": "https://www.geeksforgeeks.org/sslyze-fast-and-powerful-ssl-tls-scanning-tool/","SSLlyze by Hackingvision": "https://hackingvision.com/2017/08/11/sslyze-fast-powerful-ssltls-server-scanning-library/","SSLyze by Securecodebox": "https://www.securecodebox.io/docs/scanners/sslyze/"},method="pip")
                elif option2=="4":
                    print(f"\n[+] O-Saft")
                    os.system("clear")
                    github="O-Saft is an open-source tool designed for analyzing and detecting the security configuration issues in web applications. It mainly focuses on the security headers and their misconfigurations, which might lead to security vulnerabilities. The tool scans the website and generates a report that contains information about the misconfigured security headers, their impact, and how to fix them. O-Saft helps the developers to ensure the security of their web applications and protect them from various cyber threats."
                    template.template("o-saft","o-saft --help",github.strip(),{"O-Soft by OWASP": "https://owasp.org/www-project-o-saft/","O-Soft by Kali": "https://www.kali.org/tools/o-saft/"})
                elif option2=="5":
                    print(f"\n[+] sslscan")
                    os.system("clear")
                    github = "SSLScan is a free tool that helps in identifying SSL/TLS vulnerabilities and misconfigurations in SSL/TLS enabled servers. It scans and evaluates the SSL/TLS connection on the target server and provides a detailed report of any weak ciphers, protocols or configurations that can be exploited by attackers. SSLScan is commonly used by security professionals and penetration testers to assess the security posture of an organization's SSL/TLS infrastructure. It is available for Windows, Linux, and MacOS platforms."
                    template.template("sslscan","sslscan",github.strip(),{"SSLSCAN by Oreilly": "https://www.oreilly.com/library/view/web-penetration-testing/9781788623377/285990a3-9992-40b0-ac36-69adc6fb47ce.xhtml","SSLSCAN by ALASTA": "https://www.alasta.com/tools/2016/07/26/tools-sslscan.html"})
                elif option2=="6":
                    print(f"\n[+] SSLLabs")
                    os.system("clear")
                    github = "Skipfish is an active web application security reconnaissance tool. It prepares an interactive sitemap for the targeted site by carrying out a recursive crawl and dictionary-based probes. The resulting map is then annotated with the output from a number of active (but hopefully non-disruptive) security checks. The final report generated by the tool is meant to serve as a foundation for professional web application security assessments."
                    template.template("SSLLabs (Website)","https://www.ssllabs.com/ssltest/",github.strip(),"no-writeups",method="browser")
                else:
                    break
        elif option == "1":
            os.system("clear")
            writeup.writeup({"A02-2021 Cryptographic Failures by OWASP":"https://owasp.org/Top10/A02_2021-Cryptographic_Failures/","Cryptographic Failures by Synack":"https://www.synack.com/blog/preventing-cryptographic-failures-the-no-2-vulnerability-in-the-owasp-top-10/","Cryptographic Failures by MYF5":"https://my.f5.com/manage/s/article/K00174750","Cryptographic Failures by Qawerk":"https://qawerk.com/blog/cryptographic-failure/"},"Cryptography Failure Write-UPS")
        else:
            return

if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner, colors, template
import os
import requests
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Authentication")
        list_vulns = [
            "User enumeration",
            "Authentication bypass",
            "vulnerable remember me functionality",
            "Password reset",
            "Captcha bypass",
            "Autocomplete on ",
            "multifactor authentication",
            "Logout functionality",
            "cache management",
            "Default credentials",
            "Go back",
        ]
        for i in range(len(list_vulns)):
            print(colors.options, f"{i}) {list_vulns[i]}".title(), colors.reset)
        try:
            vulns = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if vulns == "0":
            os.system("clear")
            template.template(
                "Test for User enumeration",
                "no-tools",
                "",
                {
                    "Testing for Account Enumeration and Guessable User Account": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/03-Identity_Management_Testing/04-Testing_for_Account_Enumeration_and_Guessable_User_Account",
                    "What Is User Enumeration?": "https://www.rapid7.com/blog/post/2017/06/15/about-user-enumeration/",
                },
            )
        elif vulns == "1":
            os.system("clear")
            template.template(
                "Testing for authentication bypass",
                "no-tools",
                "",
                {
                    "Testing for Bypassing Authentication Schema": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/04-Authentication_Testing/04-Testing_for_Bypassing_Authentication_Schema",
                    "5 Unusual Authentication Bypass Techniques": "https://www.synack.com/blog/exploits-explained-5-unusual-authentication-bypass-techniques/",
                    "Authentication vulnerabilities": "https://portswigger.net/web-security/authentication",
                },
            )

        elif vulns == "2":
            os.system("clear")
            template.template(
                "Testing for vulnerable remember me functionality",
                "no-tools",
                "",
                {
                    "Testing for Vulnerable Remember Password": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/04-Authentication_Testing/05-Testing_for_Vulnerable_Remember_Password",
                    "Exploiting Remember Me Cookie For Account Takeover": "https://gupta-bless.medium.com/exploiting-remember-me-cookie-for-account-takeover-4e8d5fd42d4b",
                },
            )

        elif vulns == "3":
            os.system("clear")
            template.template(
                "Testing for Password reset",
                "no-tools",
                "",
                {
                    "Password reset poisoning": "https://portswigger.net/web-security/host-header/exploiting/password-reset-poisoning",
                    "Testing Forgot Password Functionality": "https://twitter.com/tuhin1729_/status/1437471718142976007?t=G7ODwQzc6ON2T6_DDC89jA&s=19",
                    "Exploiting Password Reset Poisoning": "https://infosecwriteups.com/exploiting-password-reset-poisoning-b748797f0661",
                },
            )

        elif vulns == "4":
            os.system("clear")
            template.template(
                "Testing for Captcha bypass",
                "no-tools",
                "",
                {
                    "CAPTCHA BYPASS TECHNIQUES !": "https://honeyakshat999.medium.com/captcha-bypass-techniques-f768521516b2",
                    "Bypass Captcha (Google reCAPTCHA)": "https://twitter.com/Aacle_/status/1586735203481161728?t=Vz4U17f1nHQzoXRUuMVDiA&s=19",
                    "Captcha Bypass Techniques": "https://github.com/harsh-bothra/learn365/blob/main/days/day31.md",
                },
            )

        elif vulns == "5":
            os.system("clear")
            template.template(
                "Test for autocomplete on",
                "no-tools",
                "",
                {
                    "Password field with autocomplete enabled ": "https://portswigger.net/kb/issues/00500800_password-field-with-autocomplete-enabled",
                    "Finding and Fixing Vulnerabilities in AutoComplete Not Disabled ": "https://www.beyondsecurity.com/scan-pentest-network-vulnerabilities-autocomplete-not-disabled",
                },
            )

        elif vulns == "6":
            os.system("clear")
            template.template(
                "Testing for multifactor authentication",
                "no-tools",
                "",
                {
                    "Testing Multi-Factor Authentication (MFA)": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/04-Authentication_Testing/11-Testing_Multi-Factor_Authentication",
                    "Testing Two-Factor Authentication": "https://research.nccgroup.com/2021/06/10/testing-two-factor-authentication/",
                    "How to Test Two-Factor Authentication: A Guide with Use Cases": "https://www.browserstack.com/guide/test-two-factor-authentication",
                },
            )

        elif vulns == "7":
            os.system("clear")
            template.template(
                "Check SSL Version, Algorithms",
                "no-tools",
                "",
                {
                    "Testing for Logout Functionality": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/06-Session_Management_Testing/06-Testing_for_Logout_Functionality",
                    "Test Cases For Logout | Test Scenarios For Logout ": "https://www.qaacharya.in/2019/06/test-cases-scenarios-for-logout.html",
                },
            )

        elif vulns == "8":
            os.system("clear")
            template.template(
                "Test for cache management",
                "no-tools",
                "",
                {
                    "Testing for Browser Cache Weaknesses": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/04-Authentication_Testing/06-Testing_for_Browser_Cache_Weaknesses",
                    "Cache Controls Explained": "https://www.virtuesecurity.com/kb/cache-controls-explained/",
                },
            )

        elif vulns == "9":
            template.template(
                "Test for Default credentials",
                "no-tools",
                "",
                {
                    "Testing for Default Credentials": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/04-Authentication_Testing/02-Testing_for_Default_Credentials",
                    "How default credentials helped this Hacker to get 13337$": "https://medium.com/@ashishrohra/how-default-credentials-helped-this-hacker-to-get-13337-s-d1504ebf95e4",
                },
            )
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print(f"Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return "{colors.red}NotLloaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner, colors, template,WEB_Application_Analysis
from cyberonix.main import Cheat_sheet
import os
import requests
from bs4 import BeautifulSoup


# main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Authorization")
        list_attacks = ["Tools", "Writeups", "Burp Extensions", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "0":
            while True:
                print("\n[+] Tools")
                os.system("clear")
                banner.main()
                banner.attack("Tools")
                list_attacks = [
                    "Burp Suite",
                    "Wireshark",
                    "OWASP ZAP",
                    "Nessus",
                    "Hydra",
                    "BeEF",
                    "Sqlmap",
                    "Metasploit",
                    "Nmap",
                    "Penetration Testers Framework (PTF)",
                    "Go Back",
                ]
                for i in range(len(list_attacks)):
                    print(
                        colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset
                    )
                try:
                    option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    template.exit_program()
                if option == "0":
                    os.system("clear")
                    WEB_Application_Analysis.burp_suite()
                elif option == "1":
                    os.system("clear")
                    github = "Wireshark is a free and open-source packet analyzer. It is used for network troubleshooting, analysis, software and communications protocol development, and education. It can be used to examine data from a live network or from a previously saved capture file. Wireshark provides a graphical user interface (GUI) for capturing and analyzing network traffic."
                    template.template(
                        "wireshark",
                        "wireshark",
                        github.strip(),
                        {
                            "Wireshark Cheat-Sheet": "https://www.comparitech.com/net-admin/wireshark-cheat-sheet",
                            "What-is-Wireshark-and-How-to-Use-it": "https://www.comptia.org/content/articles/what-is-wireshark-and-how-to-use-it ",
                            "Video Resource Wireshark": "https://www.youtube.com/playlist?list=PLBf0hzazHTGPgyxeEj_9LBHiqjtNEjsgt",
                        },
                    )
                elif option == "2":
                    os.system("clear")
                    github = "The OWASP Zed Attack Proxy (ZAP) is an easy to use integrated penetration testing tool for finding vulnerabilities in web applications.\nIt is designed to be used by people with a wide range of security experience and as such is ideal for developers and functional testers who are new to penetration testing as well as being a useful addition to an experienced pen testers toolbox."
                    template.template(
                        "zaproxy",
                        "zaproxy > /dev/null 2>&1",
                        github.strip(),
                        {
                            "How to setup OWASP ZAP to scan your web application for security vulnerabilities": "https://www.linkedin.com/pulse/how-setup-owasp-zap-scan-your-web-application-security-botla/",
                            "Authenticated Scan using OWASP-ZAP": "https://medium.com/@secureica/authenticated-scan-using-owasp-zap-f0a71dafe41",
                            "OWASP ZAP: 6 Key Capabilities and a Quick Tutorial": "https://www.hackerone.com/knowledge-center/owasp-zap-6-key-capabilities-and-quick-tutorial",
                            "Initial Setup": "https://infosecgirls.gitbook.io/infosecgirls-training/v/appsec/initial-setup-with-owasp-zap/untitled",
                            "Setup OWASP ZAP": "https://infosecgirls.gitbook.io/infosecgirls-training/v/appsec/initial-setup-with-owasp-zap/setup-owasp-zap",
                        },
                    )
                elif option == "3":
                    os.system("clear")
                    github = github_getting_text(
                        "https://www.techtarget.com/searchnetworking/definition/Nessus",
                        'section[id="content-body"]',
                        0,
                    )
                    template.template(
                        "nessus",
                        "nessus",
                        github.strip(),
                        {
                            "How To: Run Your First Vulnerability Scan with Nessus": "https://www.tenable.com/blog/how-to-run-your-first-vulnerability-scan-with-nessus",
                            "A brief introduction to the Nessus vulnerability scanner": "https://resources.infosecinstitute.com/topic/a-brief-introduction-to-the-nessus-vulnerability-scanner/",
                            "Beginner’s Guide to Nessus": "https://www.hackingarticles.in/beginners-guide-to-nessus/",
                            "Nessus Ubuntu Installation and Tutorial": "https://linuxhint.com/nessus-ubuntu-installation-tutorial/",
                        },
                        link="https://www.tenable.com/downloads/api/v2/pages/nessus/files/Nessus-10.4.2-debian9_amd64.deb",
                        method="deb",
                    )
                elif option == "4":
                    os.system("clear")
                    github_p1 = github_getting_text(
                        "https://www.kali.org/tools/hydra/", "p", 2
                    )
                    github_p2 = github_getting_text(
                        "https://www.kali.org/tools/hydra/", "p", 3
                    )
                    github_p3 = github_getting_text(
                        "https://www.kali.org/tools/hydra/", "p", 4
                    )
                    github = github_p1 + github_p2 + github_p3
                    template.template(
                        "hydra",
                        "hydra",
                        github.strip(),
                        {
                            "How to use the hydra for password cracking": "https://www.techtarget.com/searchsecurity/tutorial/How-to-use-the-Hydra-password-cracking-tool",
                            "Hydra Tool For Brute- force attack": "https://systemweakness.com/hydra-tool-for-brute-force-attack-72653db7abe9?gi=efe05fea34af",
                        },
                    )
                elif option == "5":
                    os.system("clear")
                    github_p1 = github_getting_text(
                        "https://github.com/beefproject/beef", 'p[dir="auto"]', 2
                    )
                    github_p2 = github_getting_text(
                        "https://github.com/beefproject/beef", 'p[dir="auto"]', 3
                    )
                    github = github_p1 + github_p2
                    template.template(
                        "beef-xss",
                        "beef-xss",
                        github.strip(),
                        {
                            "BEeF Hacking Framework Tutorial [5 Easy Steps]": "https://www.golinuxcloud.com/beef-hacking-framework-tutorial/",
                            "Browser Exploitation and Advanced Threat Actors: An Overview of BeEF": "https://medium.com/@andrearebora/browser-exploitation-and-advanced-threat-actors-an-overview-of-beef-bb907a5b73fa",
                            "Hooking victims to Browser Exploitation Framework (BeEF) using Reflected and Stored XSS.": "https://medium.com/@secureica/hooking-victims-to-browser-exploitation-framework-beef-using-reflected-and-stored-xss-859266c5a00a",
                            "Hijacking Browser with BeEF Framework": "https://medium.com/@krunalkumarpatel/hijacking-browser-with-beef-framework-bea784c03149",
                        },
                    )
                elif option == "6":
                    os.system("clear")
                    github = github_getting_text("https://sqlmap.org/", "p", 0)
                    template.template(
                        "sqlmap",
                        "sqlmap -h",
                        github.strip(),
                        {
                            "Usage Of Sqlmap": "https://github.com/sqlmapproject/sqlmap/wiki/Usage",
                            "How to use SQLMAP to test a website for SQL Injection vulnerability": "https://www.geeksforgeeks.org/use-sqlmap-test-website-sql-injection-vulnerability/",
                            "How to Use SQLMap to Find Database Vulnerabilities": "https://www.freecodecamp.org/news/how-to-protect-against-sql-injection-attacks/",
                            "SQLMap - Cheetsheat": "https://book.hacktricks.xyz/pentesting-web/sql-injection/sqlmap",
                        },
                    )
                elif option == "7":
                    os.system("clear")
                    github = "The Metasploit Framework is an open-source tool for developing and executing exploit code against a remote target machine. It can be used to test the security of a computer system by finding and exploiting vulnerabilities. The framework includes a large collection of exploit modules, as well as various tools for payload generation, post-exploitation, and more. It can be used by security professionals for penetration testing, as well as by attackers for malicious purposes."
                    template.template(
                        "metasploit-framework",
                        "msfconsole",
                        github.strip(),
                        {
                            "Msf-Community-Post-Exploitation": "https://www.offensive-security.com/metasploit-unleashed/msf-community-post-exploitation",
                            "Post Exploitation In Linux With Metasploit": "https://pentestlab.blog/2013/01/04/post-exploitation-in-linux-with-metasploit/",
                            "Privilege Escalation (Metasploit Unleashed)": "https://www.offensive-security.com/metasploit-unleashed/privilege-escalation/",
                            "Post Exploitation Metasploit Modules (Reference)": "https://www.infosecmatter.com/post-exploitation-metasploit-modules-reference",
                            "PSExec Pass the Hash (Horizontal Escalation)": "https://www.offensive-security.com/metasploit-unleashed/psexec-pass-hash/",
                            "ms10_002_aurora (Vertical Escalation)": "https://www.offensive-security.com/metasploit-unleashed/privilege-escalation/",
                            "ms10_002_aurora (Horizontal Escalation)": "https://www.offensive-security.com/metasploit-unleashed/pivoting/ ",
                            "jtr_crack_fast (Hash Cracking)": "https://www.offensive-security.com/metasploit-unleashed/john-ripper/",
                            "warftpd_165_user (Keylogging)": "https://www.offensive-security.com/metasploit-unleashed/keylogging/",
                            "3proxy (Backdoor)": "https://www.offensive-security.com/metasploit-unleashed/meterpreter-backdoor/",
                            "persistence.rb (Persistent Backdoor)": "https://www.offensive-security.com/metasploit-unleashed/meterpreter-service/",
                            "Enabling Remote Desktop": "https://www.offensive-security.com/metasploit-unleashed/enabling-remote-desktop/",
                            "Post Exploitation in Linux with Metasploit": "https://pentestlab.blog/2013/01/04/post-exploitation-in-linux-with-metasploit/",
                            "Post Exploitation Metasploit Modules Reference": "https://www.infosecmatter.com/post-exploitation-metasploit-modules-reference/",
                            "Hack Like Pro: Kill and Disable Antivirus Software Remote PC": "https://null-byte.wonderhowto.com/how-to/hack-like-pro-kill-and-disable-antivirus-software-remote-pc-0141906/",
                            "Armitage Post Exploitation": "https://www.offensive-security.com/metasploit-unleashed/armitage-post-exploitation/",
                            "Setup Armitage as a Command & Control Framework for Free": "https://infosecwriteups.com/setup-armitage-as-a-command-control-c2-framework-for-free-bae590064817",
                            "Event Log Management": "https://www.offensive-security.com/metasploit-unleashed/event-log-management",
                            "Interacting with the Registry": "https://www.offensive-security.com/metasploit-unleashed/interacting-registry",
                        },
                    )
                elif option == "8":
                    os.system("clear")
                    github = "Nmap (Network Mapper) is a network scanner created by Gordon Lyon (also known by his pseudonym Fyodor Vaskovich). Nmap is used to discover hosts and services on a computer network by sending packets and analyzing the responses."
                    template.template(
                        "nmap",
                        "nmap",
                        github.strip(),
                        {
                            "Nmap Cheat-Sheet": "https://www.stationx.net/nmap-cheat-sheet/",
                            "Official website": "https://nmap.org/ ",
                            "Other resources": "https://linux.die.net/man/1/nmap",
                        },
                    )
                elif option == "9":
                    os.system("clear")
                    github = "The PenTesters Framework (PTF) is a Python script designed for Debian/Ubuntu/ArchLinux based distributions to create a similar and familiar distribution for Penetration Testing. PTF attempts to install all of your penetration testing tools (latest and greatest), compile them, build them, and make it so that you can install/update your distribution on any machine. Everything is organized in a fashion that is cohesive to the Penetration Testing Execution Standard (PTES) and eliminates a lot of things that are hardly used"
                    template.template(
                        "Penetration Testers Framework (PTF)",
                        "./ptf",
                        github.strip(),
                        "no-writeups",
                        method="github",
                        github_install="git clone https://github.com/trustedsec/ptf.git && chmod +x ptf",
                        github_check="ptf",
                    )
                else:
                    break

        elif option == "1":
            os.system("clear")
            banner.main()
            Cheat_sheet.cheat(
                {
                    "Securing Applications with Better User Authorization": "https://medium.com/capital-one-tech/securing-applications-with-better-user-authorization-625ec07a7001",
                    "Access Control": "https://portswigger.net/web-security/access-control",
                    "Web Security: Authentication & Authorization": "https://coderstower.com/2020/03/23/web-security-authentication-authorization/",
                    "Authentication & Authorization in Web Apps": "https://blog.jscrambler.com/authentication-authorization-in-web-apps",
                    "Session IDs - OWASP": "https://www.cgisecurity.com/lib/SessionIDs.pdf",
                    "JWT Authorization in Web Applications": "https://concisesoftware.com/blog/jwt-authorization-in-web-applications/",
                    "Insecure Authorization": "https://www.appsealing.com/insecure-authorization/",
                    "OAuth Vulnerabilities: Implementing Secure Authorization in Your Web Application": "https://medium.com/swlh/oauth-vulnerabilities-implementing-secure-authorization-in-your-web-application-3b9517b34798",
                    "OWASP Top 10 - Broken Access Control": "https://owasp.org/Top10/A01_2021-Broken_Access_Control/",
                    "Broken Authorization Vulnerability": "https://knowledge-base.secureflag.com/vulnerabilities/broken_authorization/broken_authorization_vulnerability.html",
                    "OWASP Web Security Testing Guide - Authorization Testing": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/05-Authorization_Testing/README",
                    "Web Authentication & Authorization": "https://www.slideshare.net/alex_pasaila/web-authentication-authorization-10930449",
                    "Web Security - Authorization": "https://www3.rocketsoftware.com/rocketd3/support/documentation/Uniface/10/uniface/webApps/webSecurity/webSecurity_Authorization.htm",
                    "Authorization Best Practices": "https://goteleport.com/blog/authorization-best-practices/",
                    "Secure Your Web Application with Spring Security - Identify How to Secure Access to an App Using Authentication and Authorization": "https://openclassrooms.com/en/courses/5683681-secure-your-web-application-with-spring-security/6695816-identify-how-to-secure-access-to-an-app-using-authentication-and-authorization",
                    "Preventing Broken Access Control": "https://crashtest-security.com/broken-access-control-prevention/",
                    "Preventing Broken Access Control - The No. 1 Vulnerability in the OWASP Top 10 2021": "https://www.synack.com/blog/preventing-broken-access-control-the-no-1-vulnerability-in-the-owasp-top-10-2021/",
                    "A Step-by-Step Guide to Broken Access Control Attacks": "https://www.polar.security/post/a-step-by-step-guide-to-broken-access-control-attacks",
                    "Broken-Access-Control - packetlabs": "https://www.packetlabs.net/posts/broken-access-control",
                    "Broken-Access-Control - qawerk": "https://qawerk.com/blog/broken-access-control/",
                    "Testing for Broken Authentication in Web Apps": "https://www.section.io/engineering-education/testing-for-broken-authentication-in-web-apps/",
                    "Broken-Access-Control (javascript) - Snyk": "https://learn.snyk.io/lessons/broken-access-control/javascript/",
                    "JSON Web Tokens Decoder - JWT.IO": "https://jwt.io/",
                    "Authorization Code Grant - Zine": "https://pbs.twimg.com/media/Et2T02KVcAEONV0?format=jpg&name=large",
                    "OWASP API1: 2019 – Broken Object Level Authorization": "https://securityboulevard.com/2023/02/owasp-api1-2019-broken-object-level-authorization/",
                    "BOLA: 3-Digit Bounty from Topcoder": "https://infosecwriteups.com/what-is-bola-3-digit-bounty-from-topcoder-a25e7fae0d64",
                    "Broken Function Level Authorization (API Security) 0x2": "https://infosecwriteups.com/broken-function-level-authorization-api-security-0x2-23a6d7c1aa46",
                    "A Deep Dive on the Most Critical API Vulnerability: BOLA": "https://inonst.medium.com/a-deep-dive-on-the-most-critical-api-vulnerability-bola-1342224ec3f2",
                    "Broken Object Level Authorization (BOLA) - NordiAPIs": "https://nordicapis.com/what-is-broken-object-level-authorization-and-how-to-fix-it/",
                    "Broken Function Level Authorization Leads to Disclosing PII Information of All Company Users": "https://webresearcher007.medium.com/broken-function-level-authorization-leads-to-disclosing-pii-information-of-all-company-users-35aee60b287b",
                },
                "Authorization Write-UPS",
            )

        elif option == "2":
            print("\n[+] Burp Extensions")
            os.system("clear")
            banner.main()
            Cheat_sheet.cheat(
                {
                    "Portswigger - Auth Analyzer": "https://portswigger.net/bappstore/7db49799266c4f85866f54d9eab82c89",
                    "Github - Auth Analyzer": "https://github.com/simioni87/auth_analyzer",
                    "Portswigger - AutoRepeater": "https://portswigger.net/bappstore/f89f2837c22c4ab4b772f31522647ed8",
                    "Github - AutoRepeater": "https://github.com/nccgroup/AutoRepeater",
                    "Github - Burp-SessionAuthTool": "https://github.com/thomaspatzke/Burp-SessionAuthTool",
                    "Github - BurpAuthzPlugin": "https://github.com/wuntee/BurpAuthzPlugin",
                    "Github - Burp-uuid": "https://github.com/silentsignal/burp-uuid",
                    "Github - Autorize": "https://github.com/Quitten/Autorize",
                    "Github - AuthMatrix": "https://github.com/SecurityInnovation/AuthMatrix",
                    "Github - Burplay": "https://github.com/SpiderLabs/burplay",
                    "Github - Param-Miner": "https://github.com/PortSwigger/param-miner",
                    "Portswigger - SAML Raider": "https://portswigger.net/bappstore/c61cfa893bb14db4b01775554f7b802e",
                    "Portswigger - Authz": "https://portswigger.net/bappstore/4316cc18ac5f434884b2089831c7d19e",
                },
                "Authorization Burp Extensions",
            )

        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()



from bs4 import BeautifulSoup
from cyberonix.main.tools import banner,colors,template
import os
import requests
from bs4 import BeautifulSoup

def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Wireless Hacking")
        list_attacks = ["Kismet", "Wifite", "Fern Wifi Cracker",
                        "Aircrack-ng", "Fluxion", "Wifiphisher", "go back"]
        for i in range(len(list_attacks)):
            print(colors.options,f"{i}) {list_attacks[i]}".title(),colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "0":
            print("\n[+] Kismet")
            github = github_getting_text("https://github.com/kismetwireless/kismet-docs/blob/master/readme/000-intro.md", 'p[dir="auto"]', 0)
            template.template("kismet","kismet",github.strip(),{"Kismet -- WiFi Sniffer": "https://www.kalilinux.in/2019/02/kismet-wifi-sniffer.html", "Use Kismet to Watch Wi-Fi User Activity": "https://null-byte.wonderhowto.com/how-to/use-kismet-watch-wi-fi-user-activity-through-walls-0182214/",
                    "HACKING WIFI USING KISMET": "https://www.bookofnetwork.com/hacking-tutorials/Kismet-Wireless", "How To Use Kismet Kali Linux?": "https://www.systranbox.com/how-to-use-kismet-kali-linux/"})
        elif option == "1":
            print("\n[+] Wifite")
            github = github_getting_text("https://www.kali.org/tools/wifite/", 'p', 1)
            template.template("wifite","wifite -h",github.strip(),{"Wifite walkthrough Part-1": "https://resources.infosecinstitute.com/topic/wifite-walkthrough-part-1/", "Wifite walkthrough Part-2": "https://resources.infosecinstitute.com/topic/wifite-walkthrough-part-2/",
                    "Wireless pentesting with Wifite": "https://www.hackingarticles.in/wireless-penetration-testing-wifite/", "Wifite - Automated Wifi hacking tool": "https://kalitut.com/wifite-automated-wi-fi-hacking-tool/"})
        elif option == "2":
            print("\n[+] Fern Wifi Cracker")
            github = github_getting_text("https://github.com/savio-code/fern-wifi-cracker", 'p[dir="auto"]', 0)
            template.template("fern-wifi-cracker","fern-wifi-cracker",github.strip(),{"What is Fern Wifi Cracker": "https://www.kalilinux.in/2020/09/fern-wifi-cracker.html", "Hacking Wifi networks using Fern Wifi Cracker": "https://www.studocu.com/en-au/document/western-sydney-university/it-product-support-and-services/fern-wifi-cracker-hacking-wifi-networks-using-fern-wifi-cracker-easily/10772514",
                    "Wireless penetration testing - Fern ": "https://www.hackingarticles.in/wireless-penetration-testing-fern/", "Cracking wifi passwords using Fern": "https://hacking84.rssing.com/chan-13108703/article238.html"})
        elif option == "3":
            print("\n[+] Aircrack-ng")
            github = github_getting_text("https://www.kali.org/tools/aircrack-ng/", 'p', 32)
            template.template("aircrack-ng","aircrack-ng --help",github.strip(),{"How to use Aircrack-ng": "https://linuxhint.com/how_to_aircrack_ng/", "Aircrack-ng Practical Demonstration Tutorial": "https://techofide.com/blogs/how-to-use-aircrack-ng-aircrack-ng-tutorial-practical-demonstration/",
                    "Hacking the wireless network in 5 simple steps": "https://www.hackingloops.com/how-to-use-aircrack-kali/", "Crack WPA/WPA2 WiFi Passwords using Aircrack-ng & Kali Linux": "https://nooblinux.com/crack-wpa-wpa2-wifi-passwords-using-aircrack-ng-kali-linux/"})
        elif option == "4":
            print("\n[+] Fluxion")
            github = github_getting_text("https://github.com/FluxionNetwork/fluxion", 'p[dir="auto"]', 1)
            template.template("fluxion","./fluxion.sh -h",github.strip(),{"Fluxion kali linux tutorial": "https://linuxhint.com/fluxion-kali-linux-tutorial/", "Fluxion - Wifi security auditing tool": "https://www.hackingloops.com/fluxion/", "Fluxion -- Crack WiFi Passwords in Minutes": "https://www.kalilinux.in/2020/07/fluxion-kali-linux-crack-wifi.html",
                    "Cracking WPA/WPA2 Passwords in Minutes with Fluxion": "https://gbhackers.com/cracking-wpawpa2-passwords-fluxion/amp/", "Wireless Penetration Testing: Fluxion": "https://www.hackingarticles.in/wireless-penetration-testing-fluxion/", "Fluxion in Kali Linux usage": "https://www.cyberpratibha.com/blog/fluxion-wpa-wpa2-hacking/"}, github_install="git clone https://github.com/FluxionNetwork/fluxion.git",method="github",github_check="fluxion")
        elif option == "5":
            print("\n[+] Wifiphisher")
            github = github_getting_text("https://github.com/wifiphisher/wifiphisher", 'p[dir="auto"]', 2)
            template.template("wifiphisher","wifiphisher -h",github.strip(),{"WiFi Exploitation with WifiPhisher": "https://www.hackingarticles.in/wifi-exploitation-wifiphisher/", "wifiphisher Description": "https://en.kali.tools/?p=90", "Read Team engagement on Wifi with Wifiphisher": "https://whitehatinstitute.com/conduct-red-team-engagements-on-wifi-with-wifiphisher/", "Wireless Hacking with WifiPhisher": "https://cntemngwa.medium.com/wireless-hacking-with-wifiphisher-d4b857414146", "WifiPhisher – WiFi Crack and Phishing Framework": "https://latesthackingnews.com/2018/10/02/wifiphisher-wifi-crack-and-phishing-framework/", "Wifiphisher Evil Twin Attack": "https://kalitut.com/wifiphisher-evil-twin-attack/"})
                    
        else:
            return


def github_getting_text(link,selector,indexvalue):
    print("Please Wait....\r",end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, 'html.parser')
        paras = soup.select(selector)
        #check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"

if __name__=='__main__':
    main()



from cyberonix.main.tools import banner, colors, template,WEB_Application_Analysis
from cyberonix.main import Cheat_sheet
import os
import requests
from bs4 import BeautifulSoup


# main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Risky Functionality Card Payment")
        list_attacks = ["Tools", "Writeups", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "0":
            while True:
                print("\n[+] Tools")
                os.system("clear")
                banner.main()
                banner.attack("Tools")
                list_attacks = [
                    "Burp Suite",
                    "Wireshark",
                    "OWASP ZAP",
                    "Nessus",
                    "Sqlmap",
                    "Fiddler",
                    "Metasploit",
                    "Nmap",
                    "Penetration Testers Framework (PTF)",
                    "Go Back",
                ]
                for i in range(len(list_attacks)):
                    print(
                        colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset
                    )
                try:
                    option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    template.exit_program()
                if option == "0":
                    os.system("clear")
                    WEB_Application_Analysis.burp_suite()
                elif option == "1":
                    os.system("clear")
                    github = "Wireshark is a free and open-source packet analyzer. It is used for network troubleshooting, analysis, software and communications protocol development, and education. It can be used to examine data from a live network or from a previously saved capture file. Wireshark provides a graphical user interface (GUI) for capturing and analyzing network traffic."
                    template.template(
                        "wireshark",
                        "wireshark",
                        github.strip(),
                        {
                            "Wireshark Cheat-Sheet": "https://www.comparitech.com/net-admin/wireshark-cheat-sheet",
                            "What-is-Wireshark-and-How-to-Use-it": "https://www.comptia.org/content/articles/what-is-wireshark-and-how-to-use-it ",
                            "Video Resource Wireshark": "https://www.youtube.com/playlist?list=PLBf0hzazHTGPgyxeEj_9LBHiqjtNEjsgt",
                        },
                    )
                elif option == "2":
                    os.system("clear")
                    github = "The OWASP Zed Attack Proxy (ZAP) is an easy to use integrated penetration testing tool for finding vulnerabilities in web applications.\nIt is designed to be used by people with a wide range of security experience and as such is ideal for developers and functional testers who are new to penetration testing as well as being a useful addition to an experienced pen testers toolbox."
                    template.template(
                        "zaproxy",
                        "zaproxy > /dev/null 2>&1",
                        github.strip(),
                        {
                            "How to setup OWASP ZAP to scan your web application for security vulnerabilities": "https://www.linkedin.com/pulse/how-setup-owasp-zap-scan-your-web-application-security-botla/",
                            "Authenticated Scan using OWASP-ZAP": "https://medium.com/@secureica/authenticated-scan-using-owasp-zap-f0a71dafe41",
                            "OWASP ZAP: 6 Key Capabilities and a Quick Tutorial": "https://www.hackerone.com/knowledge-center/owasp-zap-6-key-capabilities-and-quick-tutorial",
                            "Initial Setup": "https://infosecgirls.gitbook.io/infosecgirls-training/v/appsec/initial-setup-with-owasp-zap/untitled",
                            "Setup OWASP ZAP": "https://infosecgirls.gitbook.io/infosecgirls-training/v/appsec/initial-setup-with-owasp-zap/setup-owasp-zap",
                        },
                    )
                elif option == "3":
                    os.system("clear")
                    github = github_getting_text(
                        "https://www.techtarget.com/searchnetworking/definition/Nessus",
                        'section[id="content-body"]',
                        0,
                    )
                    template.template(
                        "nessus",
                        "nessus",
                        github.strip(),
                        {
                            "How To: Run Your First Vulnerability Scan with Nessus": "https://www.tenable.com/blog/how-to-run-your-first-vulnerability-scan-with-nessus",
                            "A brief introduction to the Nessus vulnerability scanner": "https://resources.infosecinstitute.com/topic/a-brief-introduction-to-the-nessus-vulnerability-scanner/",
                            "Beginner’s Guide to Nessus": "https://www.hackingarticles.in/beginners-guide-to-nessus/",
                            "Nessus Ubuntu Installation and Tutorial": "https://linuxhint.com/nessus-ubuntu-installation-tutorial/",
                        },
                        link="https://www.tenable.com/downloads/api/v2/pages/nessus/files/Nessus-10.4.2-debian9_amd64.deb",
                        method="deb",
                    )
                elif option == "4":
                    os.system("clear")
                    github = github_getting_text("https://sqlmap.org/", "p", 0)
                    template.template(
                        "sqlmap",
                        "sqlmap -h",
                        github.strip(),
                        {
                            "Usage Of Sqlmap": "https://github.com/sqlmapproject/sqlmap/wiki/Usage",
                            "How to use SQLMAP to test a website for SQL Injection vulnerability": "https://www.geeksforgeeks.org/use-sqlmap-test-website-sql-injection-vulnerability/",
                            "How to Use SQLMap to Find Database Vulnerabilities": "https://www.freecodecamp.org/news/how-to-protect-against-sql-injection-attacks/",
                            "SQLMap - Cheetsheat": "https://book.hacktricks.xyz/pentesting-web/sql-injection/sqlmap",
                        },
                    )
                elif option == "5":
                    os.system("clear")
                    github = github_getting_text(
                        "https://learn.microsoft.com/en-us/windows/win32/win7appqual/fiddler-web-debugger-tool/",
                        "p",
                        2,
                    )
                    template.template(
                        "Fiddler",
                        "chmod u+x fiddler-everywhere-4.1.2.AppImage && su -c ./fiddler-everywhere-4.1.2.AppImage $SUDO_USER > /dev/null 2>&1",
                        github.strip(),
                        "no-writeups",
                        method="github",
                        github_install="wget -q --show-progress https://downloads.getfiddler.com/linux/fiddler-everywhere-4.1.2.AppImage && mkdir Fiddler_Everywhere && mv fiddler-everywhere-4.1.2.AppImage Fiddler_Everywhere",
                        github_check="Fiddler_Everywhere",
                    )
                elif option == "6":
                    os.system("clear")
                    github = "The Metasploit Framework is an open-source tool for developing and executing exploit code against a remote target machine. It can be used to test the security of a computer system by finding and exploiting vulnerabilities. The framework includes a large collection of exploit modules, as well as various tools for payload generation, post-exploitation, and more. It can be used by security professionals for penetration testing, as well as by attackers for malicious purposes."
                    template.template(
                        "metasploit-framework",
                        "msfconsole",
                        github.strip(),
                        {
                            "Msf-Community-Post-Exploitation": "https://www.offensive-security.com/metasploit-unleashed/msf-community-post-exploitation",
                            "Post Exploitation In Linux With Metasploit": "https://pentestlab.blog/2013/01/04/post-exploitation-in-linux-with-metasploit/",
                            "Privilege Escalation (Metasploit Unleashed)": "https://www.offensive-security.com/metasploit-unleashed/privilege-escalation/",
                            "Post Exploitation Metasploit Modules (Reference)": "https://www.infosecmatter.com/post-exploitation-metasploit-modules-reference",
                            "PSExec Pass the Hash (Horizontal Escalation)": "https://www.offensive-security.com/metasploit-unleashed/psexec-pass-hash/",
                            "ms10_002_aurora (Vertical Escalation)": "https://www.offensive-security.com/metasploit-unleashed/privilege-escalation/",
                            "ms10_002_aurora (Horizontal Escalation)": "https://www.offensive-security.com/metasploit-unleashed/pivoting/ ",
                            "jtr_crack_fast (Hash Cracking)": "https://www.offensive-security.com/metasploit-unleashed/john-ripper/",
                            "warftpd_165_user (Keylogging)": "https://www.offensive-security.com/metasploit-unleashed/keylogging/",
                            "3proxy (Backdoor)": "https://www.offensive-security.com/metasploit-unleashed/meterpreter-backdoor/",
                            "persistence.rb (Persistent Backdoor)": "https://www.offensive-security.com/metasploit-unleashed/meterpreter-service/",
                            "Enabling Remote Desktop": "https://www.offensive-security.com/metasploit-unleashed/enabling-remote-desktop/",
                            "Post Exploitation in Linux with Metasploit": "https://pentestlab.blog/2013/01/04/post-exploitation-in-linux-with-metasploit/",
                            "Post Exploitation Metasploit Modules Reference": "https://www.infosecmatter.com/post-exploitation-metasploit-modules-reference/",
                            "Hack Like Pro: Kill and Disable Antivirus Software Remote PC": "https://null-byte.wonderhowto.com/how-to/hack-like-pro-kill-and-disable-antivirus-software-remote-pc-0141906/",
                            "Armitage Post Exploitation": "https://www.offensive-security.com/metasploit-unleashed/armitage-post-exploitation/",
                            "Setup Armitage as a Command & Control Framework for Free": "https://infosecwriteups.com/setup-armitage-as-a-command-control-c2-framework-for-free-bae590064817",
                            "Event Log Management": "https://www.offensive-security.com/metasploit-unleashed/event-log-management",
                            "Interacting with the Registry": "https://www.offensive-security.com/metasploit-unleashed/interacting-registry",
                        },
                    )
                elif option == "7":
                    os.system("clear")
                    github = "Nmap (Network Mapper) is a network scanner created by Gordon Lyon (also known by his pseudonym Fyodor Vaskovich). Nmap is used to discover hosts and services on a computer network by sending packets and analyzing the responses."
                    template.template(
                        "nmap",
                        "nmap",
                        github.strip(),
                        {
                            "Nmap Cheat-Sheet": "https://www.stationx.net/nmap-cheat-sheet/",
                            "Official website": "https://nmap.org/ ",
                            "Other resources": "https://linux.die.net/man/1/nmap",
                        },
                    )
                elif option == "8":
                    os.system("clear")
                    github = "The PenTesters Framework (PTF) is a Python script designed for Debian/Ubuntu/ArchLinux based distributions to create a similar and familiar distribution for Penetration Testing. PTF attempts to install all of your penetration testing tools (latest and greatest), compile them, build them, and make it so that you can install/update your distribution on any machine. Everything is organized in a fashion that is cohesive to the Penetration Testing Execution Standard (PTES) and eliminates a lot of things that are hardly used"
                    template.template(
                        "Penetration Testers Framework (PTF)",
                        "chmod +x ptf && ./ptf",
                        github.strip(),
                        "no-writeups",
                        method="github",
                        github_install="git clone https://github.com/trustedsec/ptf.git",
                        github_check="ptf",
                    )
                else:
                    break

        elif option == "1":
            os.system("clear")
            banner.main()
            Cheat_sheet.cheat(
                {
                    "Exploiting Payment Gateways": "https://vasuyadav0786.medium.com/exploiting-payment-gateways-97ce7af5a9cf",
                    "Let's Break Into Payment Gateways": "https://infosecwriteups.com/lets-break-into-payment-gateways-fc52523eeaca",
                    "Common Vulnerabilities in Payment Functionality": "https://dl.packetstormsecurity.net/papers/general/common-vulnerabilities.pdf",
                    "Bug Bounty Response Manipulation Leading to Payment Bypass": "https://infosecwriteups.com/bug-bounty-response-manipulation-leading-to-payment-bypass-cb5fde360b1a",
                    "Web Application Security Testing - Testing Payment Functionality": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/10-Business_Logic_Testing/10-Test-Payment-Functionality",
                    "Application Security Testing Techniques - Testing Payment Functionality": "https://www.softwaretestinghelp.com/how-to-test-application-security-web-and-desktop-application-security-testing-techniques/",
                    "Parameter Tampering Vulnerability Using 3 Different Approaches": "https://www.cobalt.io/blog/parameter-tampering-vulnerability-using-3-different-approaches",
                    "Webinar: Understanding Payment Gateway Related Vulnerabilities": "https://www.youtube.com/watch?v=oin2fplOazU",
                    "Payment Gateway Security Measures Overview": "https://yashsali7.medium.com/an-overview-of-security-measures-used-in-payment-gateways-86375eb12364",
                    "Payment Bypass Vulnerability on BigBasket": "https://medium.com/@ranjeetjagtap25/payment-bypass-vulnerability-on-bigbasket-2aab137e9631",
                    "Security Features of Payment Gateway": "https://www.ukessays.com/essays/information-technology/security-features-of-payment-gateway-information-technology-essay.php",
                    "Vulnerabilities in Electronic Payment Systems (EPS)": "https://www.linkedin.com/pulse/vulnerabilities-eps-electronic-payment-systems-from-david-joao-",
                    "Security Threats to E-Commerce": "https://www.javatpoint.com/security-threat-to-e-commerce",
                    "Visa's 3-D Secure Secure Online Payment Authentication": "https://www.giac.org/paper/gsec/4380/visa-039-s-3-d-secure-secure-online-payment-authentication/107245",
                    "Researching Xiaomi's TEE": "https://research.checkpoint.com/2022/researching-xiaomis-tee/",
                    "JazzCash Payment Gateway in PHP (Prevent Amount Tampering)": "https://www.youtube.com/watch?v=JEvYSlwb-yY",
                },
                " Risky Functionality Payment Systems Write-UPS",
            )

        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()



from bs4 import BeautifulSoup
from cyberonix.main.tools import banner, template, colors
import os
import requests
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("HTML5")
        list_vulns = [
            "WEB Messaging",
            "WEB Storage SQL Injection",
            "CORS Implementation",
            "Go back",
        ]
        for i in range(len(list_vulns)):
            print(colors.options, f"{i}) {list_vulns[i]}".title(), colors.reset)
        try:
            vulns = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if vulns == "0":
            github = "Web messaging is the ability to send realtime messages from the server to the client browser. It overrides the cross domain communication problem in different domains, protocols or ports"
            template.template(
                "WEB Messaging",
                "no-tools",
                github.strip(),
                {
                    "HTML5 - Web messaging": "https://www.tutorialspoint.com/html5/html5_web_messaging.htm",
                    "Testing Web Messaging": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/11-Client-side_Testing/11-Testing_Web_Messaging",
                    "Web message manipulation": "https://portswigger.net/web-security/dom-based/web-message-manipulation",
                    "HTML5 Security: Cross Domain Messaging": "https://resources.infosecinstitute.com/topic/html5-security-cross-domain-messaging/",
                    "Testing for DOM XSS using web messages": "https://portswigger.net/burp/documentation/desktop/tools/dom-invader/web-messages",
                },
            )

        elif vulns == "1":
            github = "SQL injection testing checks if it is possible to inject data into the application so that it executes a user-controlled SQL query in the database. Testers find a SQL injection vulnerability if the application uses user input to create SQL queries without proper input validation. "
            template.template(
                "WEB Storage SQL Injection",
                "no-tools",
                github.strip(),
                {
                    "Testing Browser Storage": "https://owasp.org/www-project-web-security-testing-guide/v41/4-Web_Application_Security_Testing/11-Client_Side_Testing/12-Testing_Browser_Storage",
                    "Testing for SQL Injection": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/07-Input_Validation_Testing/05-Testing_for_SQL_Injection",
                    "Client-side SQL injection": "https://portswigger.net/kb/issues/00200332_client-side-sql-injection-stored-dom-based",
                    "Secure Implementation of HTML5's Web SQL Database": "https://code.google.com/archive/p/html5security/wikis/WebSQLDatabaseSecurity.wiki",
                },
            )

        elif vulns == "2":
            github = "Cross-origin resource sharing (CORS) is a mechanism that allows restricted resources on a web page to be requested from another domain outside the domain from which the first resource was served."
            template.template(
                "CORS implementation",
                "no-tools",
                github.strip(),
                {
                    "What is Web CORS in HTML5 ?": "https://www.geeksforgeeks.org/what-is-web-cors-in-html5/",
                    "Cross-origin resource sharing (CORS)": "https://portswigger.net/web-security/cors",
                    "Testing Cross Origin Resource Sharing": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/11-Client-side_Testing/07-Testing_Cross_Origin_Resource_Sharing",
                    "CORS Misconfiguration": "https://systemweakness.com/first-bug-bounty-program-found-cors-cross-origin-resource-sharing-misconfiguration-52c1bd3ebfe0",
                    "Advanced CORS Exploitation Techniques": "https://infosecwriteups.com/think-outside-the-scope-advanced-cors-exploitation-techniques-dad019c68397",
                    "Exploiting CORS misconfigurations for Bitcoins and bounties": "https://portswigger.net/research/exploiting-cors-misconfigurations-for-bitcoins-and-bounties",
                    "CORS - Misconfigurations & Bypass": "https://book.hacktricks.xyz/pentesting-web/cors-bypass",
                    "CORS Misconfiguration": "https://0xn3va.gitbook.io/cheat-sheets/web-application/cors-misconfiguration",
                },
            )
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner,colors,template,waiting,writeup
import os,requests
import requests
from bs4 import BeautifulSoup

def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("WEB Application Analysis")
        list_attacks=["Burp Suite","Owasp ZAP","Nikto","Wapiti","Nessus","dirb","skipfish","Nuclei","go back"]
        for i in range(len(list_attacks)):
            print(colors.options,f"{i}) {list_attacks[i]}".title(),colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option=="0":
            print(f"\n[+] Burp Suite")
            os.system("clear")
            burp_suite()
            # github = "Burp Suite is an integrated platform for performing security testing of web applications. Its various tools work seamlessly together to support the entire testing process, from initialmapping and analysis of an application's attack surface, through to finding and exploiting security vulnerabilities. Burp gives you full control, letting you combine advanced manual techniques with state-of-the-art automation, to make your work faster, more effective, and more fun."
            # template.template("Burp-Suite","burp",github.strip(),{"Top 10 tips for burpsuite":"https://medium.com/r3d-buck3t/top-10-tips-for-burp-suite-72212d22328f","Setting up burbsuite":"https://thexssrat.medium.com/setting-up-burp-suite-b0a6767d3408","Burp Suite: Do I need the professional edition?":"https://thexssrat.medium.com/burp-suite-do-i-need-the-professional-edition-bf8c87ce236e","Burp Suite Extensions to help you Pentest":"https://medium.com/codex/burp-suite-extensions-to-help-you-pentest-97f22a7d7d4d","FIND MORE resources here":"https://medium.com/search?q=burpsuite"},link="https://github.com/hardikhacker/Burp-Suite",method="github")
        elif option=="1":
            print(f"\n[+] Owasp ZAP")
            os.system("clear")
            github = "The OWASP Zed Attack Proxy (ZAP) is an easy to use integrated penetration testing tool for finding vulnerabilities in web applications.\nIt is designed to be used by people with a wide range of security experience and as such is ideal for developers and functional testers who are new to penetration testing as well as being a useful addition to an experienced pen testers toolbox. https://www.owasp.org/index.php/ZAP"
            template.template('zaproxy','zaproxy',github.strip(),{"How to setup OWASP ZAP to scan your web application for security vulnerabilities":"https://www.linkedin.com/pulse/how-setup-owasp-zap-scan-your-web-application-security-botla/","Authenticated Scan using OWASP-ZAP":"https://medium.com/@secureica/authenticated-scan-using-owasp-zap-f0a71dafe41","OWASP ZAP: 6 Key Capabilities and a Quick Tutorial":"https://www.hackerone.com/knowledge-center/owasp-zap-6-key-capabilities-and-quick-tutorial","Initial Setup":"https://infosecgirls.gitbook.io/infosecgirls-training/v/appsec/initial-setup-with-owasp-zap/untitled","Setup OWASP ZAP":"https://infosecgirls.gitbook.io/infosecgirls-training/v/appsec/initial-setup-with-owasp-zap/setup-owasp-zap"})
        elif option=="2":
            print("\n[+] Nikto")
            os.system("clear")
            github=github_getting_text("https://en.wikipedia.org/wiki/Nikto_(vulnerability_scanner)",'p',1)
            template.template("nikto","nikto -h",github.strip(),{'What is Nikto and it’s usages ?':'https://www.geeksforgeeks.org/what-is-nikto-and-its-usages/','Nikto: A Practical Website Vulnerability Scanner':'https://securitytrails.com/blog/nikto-website-vulnerability-scanner','Nikto Official Docs':'https://github.com/sullo/nikto/wiki'})
        elif option=="3":
            print("\n[+] Wapiti")
            os.system("clear")
            github=github_getting_text("https://github.com/wapiti-scanner/wapiti",'p[dir="auto"]',6)
            template.template("wapiti","wapiti",github.strip(),{"wapiti free web application vulnerability scanner":"https://pentestit.medium.com/wapiti-free-web-application-vulnerability-scanner-ce7712adf644","Official docs":"https://github.com/wapiti-scanner/wapiti","wapiti tutorial":"https://www.kalilinux.in/2021/01/wapiti-tutorial.html","complete guide to using wapiti web vulnerability scanner to keep your web applications websites secure":"https://linuxsecurity.com/features/complete-guide-to-using-wapiti-web-vulnerability-scanner-to-keep-your-web-applications-websites-secure"})
        elif option=="4":
            print(f"\n[+] Nessus")
            os.system("clear")
            github=github_getting_text("https://www.techtarget.com/searchnetworking/definition/Nessus",'section[id="content-body"]',0)
            template.template("nessus","nessus",github.strip(),{"How To: Run Your First Vulnerability Scan with Nessus":"https://www.tenable.com/blog/how-to-run-your-first-vulnerability-scan-with-nessus","A brief introduction to the Nessus vulnerability scanner":"https://resources.infosecinstitute.com/topic/a-brief-introduction-to-the-nessus-vulnerability-scanner/","Beginner’s Guide to Nessus":"https://www.hackingarticles.in/beginners-guide-to-nessus/","Nessus Ubuntu Installation and Tutorial":"https://linuxhint.com/nessus-ubuntu-installation-tutorial/"},link="https://www.tenable.com/downloads/api/v2/pages/nessus/files/Nessus-10.5.0-debian10_amd64.deb",method="deb")
        elif option=="5":
            print(f"\n[+] dirb")
            os.system("clear")
            github = "DIRB IS a Web Content Scanner. It looks for existing (and/or hidden) Web Objects. It basically works by launching a dictionary basesd attack against a web server and analizing the response"
            template.template("dirb","dirb",github.strip(),{"Dirb — A web content scanner":"https://medium.com/tech-zoom/dirb-a-web-content-scanner-bc9cba624c86","Footprinting and Reconnaissance with DIRB Tool (For Security Researcher and Bug Bounty Hunters":"https://www.openbugbounty.org/blog/mas00712/footprinting-and-reconnaissance-with-dirb-tool-for-security-researcher-and-bug-bounty-hunters/","Comprehensive Guide on Dirb Tool":"https://www.hackingarticles.in/comprehensive-guide-on-dirb-tool/"})
        elif option=="6":
            print(f"\n[+] skipfish")
            os.system("clear")
            github = "Skipfish is an active web application security reconnaissance tool. It prepares an interactive sitemap for the targeted site by carrying out a recursive crawl and dictionary-based probes. The resulting map is then annotated with the output from a number of active (but hopefully non-disruptive) security checks. The final report generated by the tool is meant to serve as a foundation for professional web application security assessments."
            template.template("skipfish","skipfish -h",github.strip(),{"Skipfish in Kali Linux":"https://www.javatpoint.com/skipfish-in-kali-linux","Skipfish – Penetration Testing tool in Kali Linux":"https://www.geeksforgeeks.org/skipfish-penetration-testing-tool-in-kali-linux/","skipfish (1) - Linux Man Pages":"https://www.systutorials.com/docs/linux/man/1-skipfish/","Skipfish – Web Application Security Scanner for XSS, SQL Injection, Shell injection":"https://gbhackers.com/skipfish-web-application-security-scanner/"})
        elif option=="7":
            print(f"\n[+] Nuclei")
            os.system("clear")
            github=github_getting_text("https://github.com/projectdiscovery/nuclei",'p[dir="auto"]',3)
            template.template("nuclei","nuclei -h",github.strip(),{"Nuclei - Automated Vulnerability Scanning Tool":"https://allabouttesting.org/nuclei-automated-vulnerability-scanning-tool/","Nuclei – Fast and Customizable Vulnerability Scanner":"https://www.geeksforgeeks.org/nuclei-fast-and-customizable-vulnerability-scanner/","Gauing+Nuclei for Instant Bounties":"https://infosecwriteups.com/gauing-nuclei-for-instant-bounties-7a8a07979fff ","DevSecOps 101 Part 3: Scanning Live Web Applications with Nuclei":"https://escape.tech/blog/devsecops-part-iii-scanning-live-web-applications"})
        else:
            return

def github_getting_text(link,selector,indexvalue):
    print(f"Please Wait....\r",end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, 'html.parser')
        paras = soup.select(selector)
        #check index value from test file
        return paras[indexvalue].text
    except:
        return "{colors.red}NotLloaded Because No Internet Connection{colors.reset}"
def burp_suite():
        while True:
            os.system("clear")
            banner.main()
            banner.attack("Burp Suite")
            banner.description("Burp Suite is an integrated platform for performing security testing of web applications. Its various tools work seamlessly together to support the entire testing process, from initialmapping and analysis of an application's attack surface, through to finding and exploiting security vulnerabilities. Burp gives you full control, letting you combine advanced manual techniques with state-of-the-art automation, to make your work faster, more effective, and more fun.")
            ask=template.tool_writeups("burp"," "," ")
            if ask=="1":
                    try:
                        professional=input(f"{colors.blue}[+] Do You Want It's Professional Version?(Y/N){colors.reset}")
                    except KeyboardInterrupt:
                        template.exit_program()
                    if professional=="y" or professional=="Y" or professional=="Yes" or professional=="yes":
                        #clone repo
                        path = 'Burp-Suite'
                        isExist = os.path.exists(path)
                        if isExist:
                            print(f"{colors.green}[+] It Is Installed{colors.reset}")
                            try:
                                professional=input(f"{colors.blue}[+] Do You Want Run It?(Y/N){colors.reset}")
                            except KeyboardInterrupt:
                                template.exit_program()
                            if professional=="y" or professional=="Y" or professional=="Yes" or professional=="yes":
                                print(f"{colors.yellow}[+] Please Wait....{colors.reset}")
                                os.system("cd Burp-Suite && bash installed.sh > /dev/null 2>&1")
                        else:
                            os.system("git clone https://github.com/hardikhacker/Burp-Suite")
                            try:
                                professional=input(f"{colors.blue}[+] Do You Want Run It?(Y/N){colors.reset}")
                            except:
                                template.exit_program()
                            if professional=="y" or professional=="Y" or professional=="Yes" or professional=="yes":
                                print(f"{colors.yellow}[+] Please Wait....{colors.reset}")
                                os.system("cd Burp-Suite && chmod +x * && ./Kali_Linux_Setup.sh > /dev/null 2>&1")
                    else:
                        print(f"{colors.blue}[+] CHECKING OF COMMUNITY VERSION IS INSTALLED OR NOT{colors.reset}")
                        #check for installation
                        template.check_installed("burpsuite","burpsuite")
                        waiting.waiting()
            elif ask=="2":
                #first argument for dictionary(key=title,value=url) second argument for banner 
                writeup.writeup({"Top 10 tips for burpsuite":"https://medium.com/r3d-buck3t/top-10-tips-for-burp-suite-72212d22328f","Setting up burbsuite":"https://thexssrat.medium.com/setting-up-burp-suite-b0a6767d3408","Burp Suite: Do I need the professional edition?":"https://thexssrat.medium.com/burp-suite-do-i-need-the-professional-edition-bf8c87ce236e","Burp Suite Extensions to help you Pentest":"https://medium.com/codex/burp-suite-extensions-to-help-you-pentest-97f22a7d7d4d","FIND MORE resources here":"https://medium.com/search?q=burpsuite"},"Brup Suit writeup.writeup")
            else:
                break

if __name__ == "__main__": 
    main()



__all__=["template","Configuration_Management","Secure_Transmission","colors","banner","waiting","Exploitation_Tools","information_gathering","Password_Hacking","Pentesting_Bug_Bounty","PostExploitationAttacks","run_on_browser","Vulnerability_Analysis","WEB_Application_Analysis","Wireless_Hacking","Sniffing_and_Spoofing"]



from cyberonix.main.tools import banner, waiting, writeup, colors, run_on_browser
import os
import subprocess
import threading


class template:
    def __init__(
        self,
        name,
        command,
        discription,
        writeups,
        link="",
        method="kali",
        github_install="",
        github_check="",
    ):
        self.name = name
        self.command = command
        self.method = method
        self.discription = discription
        self.writeup = writeups
        self.link = link
        self.github_install = github_install
        self.github_check = github_check
        while True:
            os.system("clear")
            banner.main()
            banner.attack(self.name)
            if command!="no-tools":
                banner.description(self.discription)
            else:
                writeup.writeup(self.writeup,self.name)
                break
            ask = tool_writeups(self.name,self.writeup, self.command)
            if ask == "1":
                if self.command == "no-tools":
                    break
                else:
                    if method == "kali":
                        check_installed(self.name, self.command)
                        waiting.waiting()
                    elif method == "go":
                        which_check(self.name, self.link, self.command)
                        waiting.waiting()
                    elif method == "pip":
                        pip_install(self.name, self.command)
                        waiting.waiting()

                    elif method == "deb":
                        deb_install(self.name, self.command, self.link)
                    elif method == "browser":
                        threading.Thread(
                            target=run_on_browser.main,
                            args=(self.command,)
                        ).start()
                    elif method == "github":
                        if not os.path.isdir("Tools"):
                            os.system("mkdir Tools")
                        if os.path.exists(f"Tools/{self.github_check}"):
                            print(f"{colors.green}[+] Installed")
                            print(f"[+] It Is Installed In Your Kali{colors.reset}")
                            run = input(
                                f"{colors.blue}[+] Do You Want To Run?(y/n):{colors.reset}"
                            )
                            if run.lower() == "yes" or run.lower() == "y":
                                os.system(
                                    f"cd Tools/{self.github_check} && {self.command}"
                                )
                        else:
                            print(f"{colors.red}[-] Not Installed{colors.reset}")
                            print(f"{colors.red}[+] It Is Not Installed In Your Kali{colors.reset}")
                            installed = input(
                                f"{colors.blue}Do You Want To Install The Tool?(y/n):{colors.reset}"
                            )
                            if installed.lower() == "y" or installed.lower() == "yes":
                                os.system(f"cd Tools && {self.github_install}")
                                run = input(
                                    f"{colors.blue}[+] Do You Want To Run?(y/n):{colors.reset}"
                                )
                                if run.lower() == "yes" or run.lower() == "y":
                                    os.system(
                                        f"cd Tools/{self.github_check} && {self.command}"
                                    )
                        waiting.waiting()
            elif ask == "2":
                if self.writeup == "no-writeups":
                    pass
                else:
                    writeup.writeup(self.writeup, self.name)
            else:
                break


def tool_writeups(name,check="no-writeups", tool_check="no-tools"):
    if tool_check != "no-tools":
        print(f"{colors.options}1) Installation")
    if check != "no-writeups":
        print(f"2) Write Ups")
    print(f"3) Go Back..")
    try:
        ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
    except KeyboardInterrupt:
        exit_program()
    return ask
def exit_program():
    os.system("clear")
    banner.main()
    print("\033[38;5;105m", "[+] Thanks visit again".title())
    exit()


def check_installed(name, run_arg):
    proc = subprocess.Popen(
        [f"dpkg -s {name} 2>/dev/null"], stdout=subprocess.PIPE, shell=True
    )
    (there, notthere) = proc.communicate()
    if "install ok installed" not in there.decode():
        print(f"\n{colors.red}[+] Not Installed")
        print(f"{colors.red}[+] It Is Not Installed In Your Kali{colors.reset}")
        try:
            install = input(
            f"{colors.blue}Do You Want To Install The Tool?(y/n):{colors.reset}"
        )
        except KeyboardInterrupt:
            exit_program()
        if install.lower() == "yes" or install.lower() == "y":
            os.system(f"apt install {name} -y")
            try:
                download = input(
                f"{colors.blue}Do You Want To Run The Tool?(y/n):{colors.reset}"
            )
            except KeyboardInterrupt:
                exit_program()
            if (
                download == "y"
                or download == "Y"
                or download == "Yes"
                or download == "yes"
            ):
                if run_arg == "kismet":
                    threading.Thread(target=thread_run, args=(run_arg,)).start()
                    print(
                        f"[+] {run_arg} is started at address: http://localhost:2501 (or the address of this system) for the Kismet UI"
                    )
                    KURL = "http://localhost:2501"
                    threading.Thread(target=run_on_browser.main, args=(KURL,)).start()
                elif run_arg == "fern-wifi-cracker":
                    threading.Thread(target=thread_run, args=(run_arg,)).start()
                    print("Fern-wifi-cracker Starting...")
                else:
                    os.system(f"{run_arg}")
    else:
        print(f"{colors.green}[+] Installed")
        print(f"[+] It Is Installed In Your Kali{colors.reset}")
        try:
            download = input(
            f"{colors.blue}Do You Want To Run The Tool?(y/n):{colors.reset}"
        )
        except KeyboardInterrupt:
            exit_program()
        if download == "y" or download == "Y" or download == "Yes" or download == "yes":
            # os.system(f"{run_arg}")
            if run_arg == "kismet":
                threading.Thread(target=thread_run, args=(run_arg,)).start()
                print(
                    f"[+] {run_arg} is started at address: http://localhost:2501 (or the address of this system) for the Kismet UI"
                )
                KURL = "http://localhost:2501"
                threading.Thread(target=run_on_browser.main, args=(KURL,)).start()
            elif run_arg == "fern-wifi-cracker":
                threading.Thread(target=thread_run, args=(run_arg,)).start()
                print("Fern-wifi-cracker Starting...")
            else:
                os.system(f"{run_arg}")


def thread_run(command):
    os.system(f"{command} > /dev/null 2>&1")


def pip_install(name, run_arg):
    proc = subprocess.Popen([f"which {name}"], stdout=subprocess.PIPE, shell=True)
    (there, nothere) = proc.communicate()
    if there:
        print(f"{colors.green}[+] Installed")
        print(f"[+] It Is Installed In Your Kali{colors.reset}")
        try:
            download = input(
            f"{colors.blue}Do You Want To Run The Tool?(y/n): {colors.reset} "
        )
        except KeyboardInterrupt:
            exit_program()
        if download.lower() == "y" or download.lower() == "yes":
            os.system(f"{run_arg}")
    else:
        print(f"{colors.red}\n[+] It Is Not Installed In Your Kali{colors.reset}")
        try:
            download = input(
            f"{colors.blue}[+] Do You Want To Install It?(y/n):{colors.reset} "
        )
        except KeyboardInterrupt:
            exit_program()
        if download.lower() == "y" or download.lower() == "yes":
            os.system(f"pip install {name}")
            # os.system("go install github.com/projectdiscovery/katana/cmd/katana@latest")
            # os.system(f'sudo cp ~/go/bin/{name} /usr/bin')
            try:
                download = input(
                f"{colors.blue}\nDo You Want To Run The Tool?(y/n): {colors.reset}"
            )
            except KeyboardInterrupt:
                exit_program()
            if download.lower() == "y" or download.lower() == "yes":
                os.system(f"{run_arg}")


def which_check(name, link, run_arg):
    proc = subprocess.Popen([f"which {name}"], stdout=subprocess.PIPE, shell=True)
    (there, nothere) = proc.communicate()
    if there:
        print(f"{colors.green}[+] Installed")
        print(f"[+] It Is Installed In Your Kali{colors.reset}")
        try:
            download = input(
            f"{colors.blue}Do You Want To Run The Tool?(y/n): {colors.reset} "
        )
        except KeyboardInterrupt:
            exit_program()
        if download.lower() == "y" or download.lower() == "yes":
            os.system(f"{run_arg}")
    else:
        print(f"{colors.red}[+] Not Installed")
        print(f"{colors.red}[+] It Is Not Installed In Your Kali{colors.reset}")
        try:
            download = input(
            f"{colors.blue}[+] Do You Want To Install It?(y/n):{colors.reset} "
        )
        except KeyboardInterrupt:
            exit_program()
        if download.lower() == "y" or download.lower() == "yes":
            os.system(f"go install {link}")
            # os.system("go install github.com/projectdiscovery/katana/cmd/katana@latest")
            os.system(f"sudo cp ~/go/bin/{name} /usr/bin")
            try:
                download = input(
                f"{colors.blue}\nDo You Want To Run The Tool?(y/n): {colors.reset}"
            )
            except KeyboardInterrupt:
                exit_program()
            if download.lower() == "y" or download.lower() == "yes":
                os.system(f"{run_arg}")


def deb_install(name, command, link):
    proc = subprocess.Popen(
        [f"dpkg -s {command} 2>/dev/null"], stdout=subprocess.PIPE, shell=True
    )
    (there, notthere) = proc.communicate()
    if "install ok installed" not in there.decode():
        print(f"{colors.red}[+] Not Installed")
        print(f"{colors.red}[+] It Is Not Installed In Your Kali{colors.reset}")
        try:
            install = input(
            f"{colors.blue}Do You Want To Install The Tool?(y/n):{colors.reset}"
        )
        except KeyboardInterrupt:
            exit_program()
        if install.lower() == "yes" or install.lower() == "y":
            if not os.path.exists(f"Tools/{link.split('/')[-1]}"):
                os.system(f"wget {link} -O Tools/{link.split('/')[-1]} ")
            os.system(f"dpkg -i Tools/{link.split('/')[-1]} ")
            try:
                install = input(
                f"{colors.blue}Do you want to run the tool?(y/n):{colors.reset}"
            )
            except KeyboardInterrupt:
                exit_program()
            if install.lower() == "y" or install.lower == "yes":
                if command == "nessus":
                    os.system("systemctl start nessusd.service")
                    print(f"{colors.green}[+] Service Started....")
                    print(
                        f"{colors.blue}[+] YOU CAN CHECK IT'S WRITE UPS FOR MORE INFO{colors.reset}"
                    )
                    try:
                        use = input(
                        f"{colors.blue}[+] Do You Want To Configure Nessus?(y/n):{colors.reset}"
                    )
                    except KeyboardInterrupt:
                        exit_program()
                    if use == "y" or use == "Y" or use == "Yes" or use == "yes":
                        run_on_browser.main("https://localhost:8834/")
                else:
                    os.system(f"{command} 2>/dev/null")
    else:
        print(f"{colors.green}[+] Installed")
        print(f"[+] It Is Installed In Your Kali{colors.reset}")
        try:
            download = input(
            f"{colors.blue}Do You Want To Run The Tool?(y/n):{colors.reset}"
        )
        except KeyboardInterrupt:
            exit_program()
        if download.lower() == "y" or download.lower() == "yes":
            if command == "nessus":
                os.system("systemctl start nessusd.service")
                print(f"{colors.green}[+] Service Started....")
                print(
                    f"{colors.blue}[+] YOU CAN CHECK IT'S WRITE UPS FOR MORE INFO{colors.reset}"
                )
                try:
                    use = input(
                    f"{colors.blue}[+] Do You Want To Configure Nessus?(y/n):{colors.reset}"
                )
                except KeyboardInterrupt:
                    exit_program()
                if use == "y" or use == "Y" or use == "Yes" or use == "yes":
                    run_on_browser.main("https://localhost:8834/")
            else:
                os.system(f"{command} 2>/dev/null")



from cyberonix.main.tools import banner, colors, template
from cyberonix.main import Cheat_sheet
import os
import requests
from bs4 import BeautifulSoup


# main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Configuration Management")
        list_attacks = ["Tools", "Writeups", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "0":
            while True:
                print("\n[+] Tools")
                os.system("clear")
                banner.main()
                banner.attack("Tools")
                list_attacks = [
                    " Dirb",
                    " Gobuster",
                    " Nikto",
                    " Wfuzz",
                    " Skipfish",
                    " Dirbuster",
                    " Feroxbuster",
                    " Nmap",
                    " HTTPie",
                    " Metasploit",
                    "SecurityHeaders",
                    "SQLmap",
                    "TruffleHog",
                    "Gitleaks",
                    "SecretFinder",
                    "Go Back"
                ]
                for i in range(len(list_attacks)):
                    print(
                        colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset
                    )
                try:
                    option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    template.exit_program()
                if option == "0":
                    print("\n[+] Dirb")
                    os.system("clear")
                    github = "Dirb is a web application scanner tool that is commonly used for reconnaissance and information gathering during web application testing. It can be used to brute-force common directory and file names on a web server, and is often used by penetration testers and security professionals to identify potential vulnerabilities in web applications. By running Dirb on a target web application, testers can quickly identify common directories and files that may contain sensitive information or be vulnerable to attack. This can help to guide further testing efforts and improve the overall security posture of the web application."
                    template.template(
                        "dirb",
                        "dirb",
                        github.strip(),
                        {
                            "Using Dirb to Find Hidden Directories": "https://www.hackers-arise.com/post/2016/12/13/web-app-hacling-part-4-using-dirb-to-find-hidden-directories",
                            "Comprehensive Guide on Dirb Tool": "https://www.hackingarticles.in/comprehensive-guide-on-dirb-tool/",
                            "How Dirb works": "https://infosecaddicts.com/dirb-is-a-web-content-scanner/",
                        },
                    )
                elif option == "1":
                    print("\n[+] Gobuster")
                    os.system("clear")
                    github = """Gobuster is an open-source tool used by security professionals and penetration testers to perform web content discovery and directory/file enumeration on a target website. It is a popular tool used in bug bounty hunting and vulnerability assessments. The tool works by launching a series of HTTP requests to the target website and analyzing the responses to discover hidden directories, files, and other web resources that may not be easily discoverable through normal browsing. It uses a wordlist of common directory and file names, as well as brute-force techniques to guess the names of hidden directories and files."""
                    template.template(
                        "gobuster",
                        "gobuster -h",
                        github.strip(),
                        {
                            "Gobuster Complete tutorial": "https://hackertarget.com/gobuster-tutorial/",
                            "Scan Websites for Interesting Directories using Gobuster": "https://null-byte.wonderhowto.com/how-to/scan-websites-for-interesting-directories-files-with-gobuster-0197226/",
                            "How to use Gobuster for Scanning Website’s Subdomains & Directories": "https://spinningsecurity.com/how-to-use-gobuster-for-scanning-websites/",
                        },
                    )
                elif option == "2":
                    print("\n[+] Nikto")
                    os.system("clear")
                    github = "Nikto is an open-source web server scanner used by security professionals and penetration testers to identify vulnerabilities and misconfigurations in web servers and web applications. It is a popular tool used in bug bounty hunting and vulnerability assessments. The tool works by launching a series of HTTP requests to the target website and analyzing the responses to identify potential security issues. It checks for known vulnerabilities and misconfigurations in the web server, including outdated software versions, insecure server configurations, and other common security issues."
                    template.template(
                        "nikto",
                        "nikto --help",
                        github.strip(),
                        {
                            "Nikto overview and usage": "https://securitytrails.com/blog/nikto-website-vulnerability-scanner",
                            "How to find Web Server Vulnerabilities with Nikto Scanner": "https://geekflare.com/nikto-webserver-scanner/",
                            "Nikto Commands in details": "https://www.mankier.com/1/nikto",
                        },
                    )
                elif option == "3":
                    print("\n[+] Wfuzz")
                    os.system("clear")
                    github = "Wfuzz is a web application brute force tool used to identify web application vulnerabilities by scanning web content, such as directories and files, for hidden or non-linked content. Wfuzz can be used to test input validation, error handling, and access control mechanisms. It is a command-line tool and allows users to customize requests to send payloads, which makes it very flexible and powerful for web application penetration testing. Wfuzz is written in Python and can be used on Linux, Windows, and macOS. It is open-source and free to use."
                    template.template(
                        "wfuzz", "wfuzz --help", github.strip(), "no-writeups"
                    )
                elif option == "4":
                    print("\n[+] Skipfish")
                    os.system("clear")
                    github = "Skipfish is an open-source web application security scanner that is commonly used in bug bounty hunting and vulnerability assessments. It is designed to efficiently scan large and complex web applications and identify potential security vulnerabilities. The tool works by launching a series of requests to the target website and analyzing the responses to identify potential vulnerabilities, such as SQL injection, cross-site scripting, and file inclusion vulnerabilities. Skipfish uses a combination of automated and manual techniques to identify vulnerabilities, including fuzzing and signature-based scanning."
                    template.template(
                        "skipfish",
                        "skipfish -h",
                        github.strip(),
                        {
                            "Skipfish commands in details": "https://linux.die.net/man/1/skipfish",
                        },
                    )
                elif option == "5":
                    print("\n[+] Dirbuster")
                    os.system("clear")
                    github = "DirBuster is a web application scanner designed to brute force directories and files names on web servers. It is a Java-based tool and can be used to discover hidden content, sensitive files, and directories that are not exposed through normal web browsing. DirBuster is also capable of detecting common web application vulnerabilities such as SQL injection, file inclusion, and cross-site scripting. The tool has an easy to use graphical user interface, and users can customize the wordlist to use in the directory and file name brute force. It is widely used by security professionals, penetration testers, and bug bounty hunters to identify security issues in web applications."
                    template.template(
                        "dirbuster", "dirbuster -h", github.strip(), "no-writeups"
                    )
                elif option == "6":
                    print("\n[+] Feroxbuster")
                    os.system("clear")
                    github = "Feroxbuster is an open-source content discovery and directory/file enumeration tool used in bug bounty hunting and web application security assessments. It quickly scans a target website for hidden directories, files, and other resources using a variety of techniques and generates a report of its findings."
                    template.template(
                        "feroxbuster", "feroxbuster -h", github.strip(), "no-writeups"
                    )
                elif option == "7":
                    print("\n[+] Nmap")
                    os.system("clear")
                    github = "Nmap (Network Mapper) is a network scanner created by Gordon Lyon (also known by his pseudonym Fyodor Vaskovich). Nmap is used to discover hosts and services on a computer network by sending packets and analyzing the responses."
                    template.template(
                        "nmap",
                        "nmap",
                        github.strip(),
                        {
                            "Official website": "https://nmap.org/",
                            "How To Test your Firewall Configuration with Nmap": "https://www.digitalocean.com/community/tutorials/how-to-test-your-firewall-configuration-with-nmap-and-tcpdump",
                            "Nmap Vulnerability Scanning": "https://nira.com/nmap-vulnerability-scanning/",
                            "How to test Firewall Configuration with Nmap on Linux Cloud Servers": "https://www.layerstack.com/resources/tutorials/How-to-test-Firewall-Configuration-with-Nmap-on-Linux-Cloud-Servers",
                        },
                    )
                elif option == "8":
                    print("\n[+] HTTPie")
                    os.system("clear")
                    github = "HTTPie is a command-line tool used to send HTTP requests and receive responses from a server. It is designed to be user-friendly and intuitive, with a simple syntax and easy-to-read output. HTTPie can be used to test and debug APIs, as well as interact with web services and applications. It supports various HTTP methods, data formats, and authentication methods, and can be customized with various options and configurations to suit specific use cases."
                    template.template(
                        "httpie", "httpie -h", github.strip(), "no-writeups"
                    )
                elif option == "9":
                    print("\n[+] Metasploit")
                    os.system("clear")
                    github = "The Metasploit Framework is an open-source tool for developing and executing exploit code against a remote target machine. It can be used to test the security of a computer system by finding and exploiting vulnerabilities. The framework includes a large collection of exploit modules, as well as various tools for payload generation, post-exploitation, and more. It can be used by security professionals for penetration testing, as well as by attackers for malicious purposes."
                    template.template(
                        "metasploit-framework",
                        "msfconsole",
                        github.strip(),
                        "no-writeups",
                    )
                elif option == "10":
                    print("\n[+] SecurityHeaders")
                    os.system("clear")
                    github = """SecurityHeaders is a configuration management tool that focuses on securing web applications by helping administrators configure appropriate HTTP security headers. HTTP security headers are additional response headers that can be sent by a web server to a client's browser to instruct it to follow certain security-related behaviors. For example, the "Content-Security-Policy" header can be used to restrict the types of content that a web page can load, helping to prevent cross-site scripting (XSS) attacks."""
                    template.template(
                        "securityheaders",
                        "python3 securityheaders.py -h",
                        github.strip(),
                        {
                            "Website": "https://securityheaders.com/",
                            "Securityheaders usage": "https://github.com/koenbuyens/securityheaders",
                        },
                        method="github",
                        github_install="git clone https://github.com/koenbuyens/securityheaders.git && cd securityheaders && pip install -r requirements.txt",
                        github_check="securityheaders",
                    )
                elif option == "11":
                    print("\n[+] Sqlmap")
                    os.system("clear")
                    github = github_getting_text("https://sqlmap.org/", "p", 0)
                    template.template(
                        "sqlmap",
                        "sqlmap -h",
                        github.strip(),
                        {
                            "Usage Of Sqlmap": "https://github.com/sqlmapproject/sqlmap/wiki/Usage",
                            "SQLmap Complete Tutorial": "https://hackertarget.com/sqlmap-tutorial/",
                        },
                    )
                elif option == "12":
                    print("\n[+] TruffleHog")
                    os.system("clear")
                    github = "Trufflehog is an open-source tool used for searching and identifying sensitive information and secrets, such as API keys, passwords, and private keys, in source code repositories. It is designed to scan code repositories for potential security vulnerabilities that could be exploited by attackers, and can be used in bug bounty hunting and vulnerability assessments. Trufflehog uses advanced techniques, such as entropy analysis and regular expressions, to identify potential security issues, and generates a report of its findings. It is a powerful and flexible tool that can help security professionals and developers identify potential security risks in their code."
                    template.template(
                        "trufflehog",
                        "trufflehog -h",
                        github.strip(),
                        {
                            "Usage": "https://github.com/trufflesecurity/trufflehog",
                            "Finding Secrets in Git Repos with TruffleHog": "https://materials.rangeforce.com/tutorial/2020/03/16/TruffleHog/",
                        },
                    )
                elif option == "13":
                    print("\n[+] Gitleaks")
                    os.system("clear")
                    github = "Gitleaks is an open-source tool used to scan Git repositories for sensitive information and secrets, such as passwords, API keys, and private keys. It is designed to identify potential security vulnerabilities that could be exploited by attackers, and can be used in bug bounty hunting and vulnerability assessments. Gitleaks uses a comprehensive set of rules and checks to detect potential security issues, and can be customized with various options and configurations to suit specific use cases. It generates a report of its findings, which can be used to remediate identified vulnerabilities and improve the overall security of the Git repositories. Gitleaks is a powerful and efficient tool that can help security professionals and developers identify potential security risks in their code repositories."
                    template.template(
                        "gitleaks", "gitleaks -h", github.strip(), "no-writeups"
                    )
                elif option == "14":
                    print("\n[+] SecretFinder")
                    os.system("clear")
                    github = "SecretFinder is an open-source tool used to scan web applications for sensitive information and secrets, such as API keys, passwords, and tokens. It is designed to identify potential security vulnerabilities that could be exploited by attackers, and can be used in bug bounty hunting and vulnerability assessments. SecretFinder uses a combination of static analysis and dynamic analysis techniques to discover secrets, and can be customized with various options and configurations to suit specific use cases. It generates a report of its findings, which can be used to remediate identified vulnerabilities and improve the overall security of the web application. SecretFinder is a powerful and efficient tool that can help security professionals and developers identify potential security risks in their web applications."
                    template.template(
                        "secretFinder",
                        "python3 SecretFinder.py -h",
                        github.strip(),
                        {
                            "SecretFinder demo": "https://www.briskinfosec.com/tooloftheday/toolofthedaydetail/SecretFinder",
                        },
                        method="github",
                        github_install="git clone https://github.com/m4ll0k/SecretFinder.git && cd SecretFinder && pip install -r requirements.txt",
                        github_check="SecretFinder",
                    )
                else:
                    break

        elif option == "1":
            print("\n[+] Write-UPS")
            os.system("clear")
            banner.main()
            Cheat_sheet.cheat(
                {
                    "Configuration management in penetration testing": "https://www.jasonclause.com/configuration-management-cybersecurity/#:~:text=Configuration%20management%20is%20the%20process,software%20and%20the%20associated%20settings.",
                    "How to find Exposed backup and unreferenced files": "https://securityboulevard.com/2021/08/exposed-backup-and-unreferenced-files-and-how-to-find-them/",
                    "Review Old Backup and Unreferenced Files for Sensitive Information": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/02-Configuration_and_Deployment_Management_Testing/04-Review_Old_Backup_and_Unreferenced_Files_for_Sensitive_Information",
                    "Multiple Ways to Detect HTTP Options": "https://www.hackingarticles.in/multiple-ways-to-detect-http-options/",
                    "security HTTP headers scanning and details": "https://www.atatus.com/tools/security-header",
                    "Testing for Content Security Policy": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/02-Configuration_and_Deployment_Management_Testing/12-Test_for_Content_Security_Policy",
                    "Test Network Infrastructure Configuration": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/02-Configuration_and_Deployment_Management_Testing/01-Test_Network_Infrastructure_Configuration",
                    "Testing applications in production vs. non-production benefits": "https://www.techtarget.com/searchsecurity/tip/Testing-applications-in-production-vs-non-production-benefits",
                    "How to Scan GitHub Repository for Credentials": "https://geekflare.com/github-credentials-scanner/",
                },
                "Configuration-Management Writeups",
            )

        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner, colors, template,WEB_Application_Analysis
from cyberonix.main import Cheat_sheet
import os
import requests
from bs4 import BeautifulSoup


# main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Session Management")
        list_attacks = ["Tools", "Writeups", "Burp Extensions", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "0":
            while True:
                print("\n[+] Tools")
                os.system("clear")
                banner.main()
                banner.attack("Tools")
                list_attacks = [
                    "OWASP ZAP",
                    "BurpSuite",
                    "Nikto",
                    "Nmap",
                    "Wapiti",
                    "Nessus",
                    "Nuclei",
                    "Fiddler",
                    "Penetration Testers Framework (PTF)",
                    "Go Back",
                ]
                for i in range(len(list_attacks)):
                    print(
                        colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset
                    )
                try:
                    option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    template.exit_program()
                if option == "0":
                    os.system("clear")
                    # name,command,discription,writeup,link=True,method="kali",github_install="",github_check=True
                    github = "The OWASP Zed Attack Proxy (ZAP) is an easy to use integrated penetration testing tool for finding vulnerabilities in web applications.\nIt is designed to be used by people with a wide range of security experience and as such is ideal for developers and functional testers who are new to penetration testing as well as being a useful addition to an experienced pen testers toolbox."
                    template.template(
                        "zaproxy",
                        "zaproxy > /dev/null 2>&1",
                        github.strip(),
                        {
                            "How to setup OWASP ZAP to scan your web application for security vulnerabilities": "https://www.linkedin.com/pulse/how-setup-owasp-zap-scan-your-web-application-security-botla/",
                            "Authenticated Scan using OWASP-ZAP": "https://medium.com/@secureica/authenticated-scan-using-owasp-zap-f0a71dafe41",
                            "OWASP ZAP: 6 Key Capabilities and a Quick Tutorial": "https://www.hackerone.com/knowledge-center/owasp-zap-6-key-capabilities-and-quick-tutorial",
                            "Initial Setup": "https://infosecgirls.gitbook.io/infosecgirls-training/v/appsec/initial-setup-with-owasp-zap/untitled",
                            "Setup OWASP ZAP": "https://infosecgirls.gitbook.io/infosecgirls-training/v/appsec/initial-setup-with-owasp-zap/setup-owasp-zap",
                        },
                    )
                elif option == "1":
                    os.system("clear")
                    WEB_Application_Analysis.burp_suite()
                elif option == "2":
                    os.system("clear")
                    github = github_getting_text(
                        "https://github.com/sullo/nikto/wiki/Overview-&-Description",
                        "p",
                        0,
                    )
                    template.template(
                        "nikto",
                        "nikto",
                        github.strip(),
                        {
                            "What is nikto and its usages": "https://www.geeksforgeeks.org/what-is-nikto-and-its-usages/",
                            "Nikto website vulnerability scanner": "https://securitytrails.com/blog/nikto-website-vulnerability-scanner",
                            "Nikto webserver scanner": "https://geekflare.com/nikto-webserver-scanner/",
                            "What is Nikto Tool in Kali and how to use it?": "https://www.cyber-today.com/what-is-nikto-tool-in-kali-and-how-to-use-it/",
                            "Basic Testing": "https://github.com/sullo/nikto/wiki/Basic-Testing",
                        },
                    )
                elif option == "3":
                    os.system("clear")
                    github = "Nmap (Network Mapper) is a network scanner created by Gordon Lyon (also known by his pseudonym Fyodor Vaskovich). Nmap is used to discover hosts and services on a computer network by sending packets and analyzing the responses."
                    template.template(
                        "nmap",
                        "nmap",
                        github.strip(),
                        {
                            "Nmap Cheat-Sheet": "https://www.stationx.net/nmap-cheat-sheet/",
                            "Official website": "https://nmap.org/ ",
                            "Other resources": "https://linux.die.net/man/1/nmap",
                        },
                    )
                elif option == "4":
                    os.system("clear")
                    github = github_getting_text(
                        "https://github.com/wapiti-scanner/wapiti", 'p[dir="auto"]', 6
                    )
                    template.template(
                        "wapiti",
                        "wapiti -h | head -30",
                        github.strip(),
                        {
                            "wapiti free web application vulnerability scanner": "https://pentestit.medium.com/wapiti-free-web-application-vulnerability-scanner-ce7712adf644",
                            "Official docs": "https://github.com/wapiti-scanner/wapiti",
                            "wapiti tutorial": "https://www.kalilinux.in/2021/01/wapiti-tutorial.html",
                            "complete guide to using wapiti web vulnerability scanner to keep your web applications websites secure": "https://linuxsecurity.com/features/complete-guide-to-using-wapiti-web-vulnerability-scanner-to-keep-your-web-applications-websites-secure",
                        },
                    )
                elif option == "5":
                    os.system("clear")
                    github = github_getting_text(
                        "https://www.techtarget.com/searchnetworking/definition/Nessus",
                        'section[id="content-body"]',
                        0,
                    )
                    template.template(
                        "nessus",
                        "nessus",
                        github.strip(),
                        {
                            "How To: Run Your First Vulnerability Scan with Nessus": "https://www.tenable.com/blog/how-to-run-your-first-vulnerability-scan-with-nessus",
                            "A brief introduction to the Nessus vulnerability scanner": "https://resources.infosecinstitute.com/topic/a-brief-introduction-to-the-nessus-vulnerability-scanner/",
                            "Beginner’s Guide to Nessus": "https://www.hackingarticles.in/beginners-guide-to-nessus/",
                            "Nessus Ubuntu Installation and Tutorial": "https://linuxhint.com/nessus-ubuntu-installation-tutorial/",
                        },
                        link="https://www.tenable.com/downloads/api/v2/pages/nessus/files/Nessus-10.4.2-debian9_amd64.deb",
                        method="deb",
                    )
                elif option == "6":
                    os.system("clear")
                    github = github_getting_text(
                        "https://github.com/projectdiscovery/nuclei", 'p[dir="auto"]', 3
                    )
                    template.template(
                        "nuclei",
                        "nuclei --help",
                        github.strip(),
                        {
                            "Nuclei - Automated Vulnerability Scanning Tool": "https://allabouttesting.org/nuclei-automated-vulnerability-scanning-tool/",
                            "Nuclei – Fast and Customizable Vulnerability Scanner": "https://www.geeksforgeeks.org/nuclei-fast-and-customizable-vulnerability-scanner/",
                            "Gauing+Nuclei for Instant Bounties": "https://infosecwriteups.com/gauing-nuclei-for-instant-bounties-7a8a07979fff ",
                            "DevSecOps 101 Part 3: Scanning Live Web Applications with Nuclei": "https://escape.tech/blog/devsecops-part-iii-scanning-live-web-applications",
                        },
                    )
                elif option == "7":
                    os.system("clear")
                    github = github_getting_text(
                        "https://learn.microsoft.com/en-us/windows/win32/win7appqual/fiddler-web-debugger-tool/",
                        "p",
                        2,
                    )
                    template.template(
                        "Fiddler",
                        "mono Fiddler.exe",
                        github.strip(),
                        "no-writeups",
                        method="github",
                        github_install="apt-get install mono-complete -y && wget http://telerik-fiddler.s3.amazonaws.com/fiddler/fiddler-linux.zip && unzip fiddler-linux.zip -d fiddler",
                        github_check="fiddler",
                    )
                elif option == "8":
                    os.system("clear")
                    github = "The PenTesters Framework (PTF) is a Python script designed for Debian/Ubuntu/ArchLinux based distributions to create a similar and familiar distribution for Penetration Testing. PTF attempts to install all of your penetration testing tools (latest and greatest), compile them, build them, and make it so that you can install/update your distribution on any machine. Everything is organized in a fashion that is cohesive to the Penetration Testing Execution Standard (PTES) and eliminates a lot of things that are hardly used"
                    template.template(
                        "Penetration Testers Framework (PTF)",
                        "chmod +x ptf && ./ptf",
                        github.strip(),
                        "no-writeups",
                        method="github",
                        github_install="git clone https://github.com/trustedsec/ptf.git",
                        github_check="ptf",
                    )
                else:
                    break

        elif option == "1":
            os.system("clear")
            banner.main()
            Cheat_sheet.cheat(
                {
                    "Session Management - Authgear": "https://www.authgear.com/post/session-management",
                    "OWASP Session Management Cheat Sheet": "https://cheatsheetseries.owasp.org/cheatsheets/Session_Management_Cheat_Sheet.html",
                    "Session Management Overview - Secure Coding": "https://www.securecoding.com/blog/session-management-an-overview/",
                    "Session Management Best Practices - Packetlabs": "https://www.packetlabs.net/posts/session-management/",
                    "HTTP Sessions - MDN Web Docs": "https://developer.mozilla.org/en-US/docs/Web/HTTP/Session",
                    "Attacking Session Management with Burp Suite": "https://portswigger.net/support/using-burp-to-attack-session-management",
                    "Session Management Lecture Notes - Stanford": "https://crypto.stanford.edu/cs155old/cs155-spring16/lectures/10-SessionMgmt.pdf",
                    "Broken Authentication and Session Management - Crashtest Security": "https://crashtest-security.com/broken-authentication-and-session-management/",
                    "Preventing Security Voids in Web Applications - SANS Institute": "https://sansorg.egnyte.com/dl/CmpHWTzrja",
                    "PHP Session Security Management - PHP.net": "https://www.php.net/manual/en/features.session.security.management.php",
                    "Session Management in ColdFusion - CFDocs": "https://cfdocs.org/security-session-management",
                    "Comprehensive Guide on Broken Authentication and Session Management - Hacking Articles": "https://hackingarticles.in/comprehensive-guide-on-broken-authentication-session-management/",
                    "What is Session Management? - Clerk.dev": "https://clerk.dev/blog/what-is-session-management",
                    "All You Need to Know About User Session Security - SuperTokens": "https://supertokens.com/blog/all-you-need-to-know-about-user-session-security",
                    "How to Secure Authentication, Session Management, and Access Control Systems of Your Web Applications - Vaadata": "https://www.vaadata.com/blog/how-to-secure-authentication-session-management-and-access-control-systems-of-your-web-applications/",
                    "Understanding Session Management - Coveros": "https://www.coveros.com/understanding-session-management-one-of-owasp-top-10-part-1/",
                    "Broken Authentication and Session Management Tips - Hacklido": "https://hacklido.com/blog/207-broken-authentication-and-session-management-tips",
                    "Web Security Session Management Slide": "https://slideplayer.com/slide/5689194/#.XFSQwUKWre4.twitter",
                    "Attacking Session Management - OWASP": "https://owasp.org/www-pdf-archive//Attacking_Session_Management_-_Alexandre_Villas.pdf",
                    "Improving the Security of Session Management in Web Applications - OWASP": "https://owasp.org/www-pdf-archive//Improving_the_Security_of_Session_Management_in_Web_Applications_-_Philippe_De_Ryck.pdf",
                    "Session Management - OWASP 2011": "https://owasp.org/www-pdf-archive//OWASP_2011_-_Slawomir_Rozbicki_-_Session_Managemnt.pdf",
                    "Session Fixation - OWASP AppSec Research 2010": "https://owasp.org/www-pdf-archive//OWASP_AppSec_Research_2010_Session_Fixation_by_Schrank_Braun_Johns_and_Poehls.pdf",
                    "SAP Session (Fixation) Attacks and Protections - OWASP": "https://owasp.org/www-pdf-archive//SAP-Session_(Fixation)_Attacks_and_Protections-OWASP-RaulSiles_Taddong.pdf",
                    "Session Hijacking: Danger on the Network - OWASP": "https://owasp.org/www-pdf-archive//Sessi%C3%B3n_Hijacking_Peligro_en_la_Red.pdf",
                    "Mastering Session Management - Siva Ram - PDF": "https://owasp.org/www-pdf-archive//Siva_Ram-Mastering_Session_Managment.pdf",
                    "Application Session Management Best Practices": "https://auth0.com/blog/application-session-management-best-practices/",
                },
                "Session Management Write-UPS",
            )

        elif option == "2":
            print("\n[+] Burp Extensions")
            os.system("clear")
            banner.main()
            Cheat_sheet.cheat(
                {
                    "PortSwigger - Session Timeout Test": "https://portswigger.net/bappstore/c4bfd29882974712a1d69c6d8f05874e",
                    "PortSwigger - CSRF Scanner": "https://portswigger.net/bappstore/60f172f27a9b49a1b538ed414f9f27c3",
                    "PortSwigger - Token Extractor": "https://portswigger.net/bappstore/f24211fa6fcd4bbea6b21f99c5cad27a",
                    "PortSwigger - Headers Analyzer": "https://portswigger.net/bappstore/8b4fe2571ec54983b6d6c21fbfe17cb2",
                    "PortSwigger - J2EE Scan": "https://portswigger.net/bappstore/7ec6d429fed04cdcb6243d8ba7358880",
                    "PortSwigger - CO2": "https://portswigger.net/bappstore/c5071c7a7e004f72ae485e8a72911afc",
                    "PortSwigger - WS Security": "https://portswigger.net/bappstore/i5431k07za13636g0o9a1733ke7h10g3",
                    "PortSwigger - JWT Editor": "https://portswigger.net/bappstore/26aaa5ded2f74beea19e2ed8345a93dd",
                    "Github - WS-Attacker": "https://github.com/RUB-NDS/WS-Attacker",
                    "Github - logger++": "https://github.com/PortSwigger/logger-plus-plus",
                },
                "Session Management Burp Extensions",
            )

        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner,template
import requests
from bs4 import BeautifulSoup
import os,inspect

def main(date=''):
    if inspect.stack()[1].function != "main":
        if not main.called:
              main.called=True
              start(date)
    else:
        start(date='')
def exit_program():
        os.system("clear")
        banner.main()
        print("\033[38;5;105m","[+] Thanks visit again".title())

def get_news(url="https://thehackernews.com/"):
    os.system("clear")
    banner.main()
    banner.attack("News")
    res = requests.get(url)
    soup = BeautifulSoup(res.text, "html.parser")

    titles = []
    discription_post=[]
    urls = []
    posts = soup.find("div", class_="blog-posts clear")
    for post in posts.find_all("h2"):
        title = post.text.strip()
        if title and '<img alt="external link"' not in str(post):
            titles.append(title)
            urls.append(post.find_parent('a')['href'])
    discriptions = soup.find_all("div", class_="home-desc")
    for discription in discriptions:
        discription=discription.text.strip()
        if title and '<img alt="external link"' not in str(discription):
            discription_post.append(discription)

    dates = []
    for date in soup.find_all("span", class_="h-datetime"):
        if '<img alt="external link"' not in str(date):
            dates.append(date.text.strip()[1:])

    for title, date, url,description in zip(titles, dates, urls,discription_post):
        print(f"\n\u001b[33mTitle: {title}\u001b[0m \n\u001b[32mdescription: {description}\u001b[0m  \nDate: {date} \n\u001b[34mURL: {url}\u001b[0m \n\n")
    input("\u001b[31mPress ENTER to go back\u001b[0m")
def start(date=''):

        os.system("clear")
        banner.main()
        banner.attack("News")
        if date=='':
            try:
                ask=input("Do you want news Date wise?(y/n)".title())
            except KeyboardInterrupt:
                      template.exit_program()
            if ask.lower()=="y" or ask.lower()=="y":
                try:
                    date_user=input("Enter Date:(YYYY-MM-DD)")
                except KeyboardInterrupt:
                      template.exit_program()
                get_news(f"https://thehackernews.com/search?updated-max={date_user}T17:23:00%2B05:30&max-results=10")
            else:
                get_news()
        else:
            get_news(f"https://thehackernews.com/search?updated-max={date}T17:23:00%2B05:30&max-results=10")
        exit_program()
main.called=False

if __name__=="__main__":
    main()
